@@ -35,13 +35,13 @@ class CorrelationFunctions(Benchmark):
         self.a = a
 
     def time_fisher_exact(self, alternative):
-        oddsratio, pvalue = stats.fisher_exact(self.a, alternative=alternative)
+        stats.fisher_exact(self.a, alternative=alternative)
 
     def time_barnard_exact(self, alternative):
-        resBarnard = stats.barnard_exact(self.a, alternative=alternative)
+        stats.barnard_exact(self.a, alternative=alternative)
 
     def time_boschloo_exact(self, alternative):
-        resBoschloo = stats.boschloo_exact(self.a, alternative=alternative)
+        stats.boschloo_exact(self.a, alternative=alternative)
 
 
 class ANOVAFunction(Benchmark):
@@ -52,8 +52,8 @@ class ANOVAFunction(Benchmark):
         self.c = rng.random((6,3)) * 10
 
     def time_f_oneway(self):
-        statistic, pvalue = stats.f_oneway(self.a, self.b, self.c)
-        statistic, pvalue = stats.f_oneway(self.a, self.b, self.c, axis=1)
+        stats.f_oneway(self.a, self.b, self.c)
+        stats.f_oneway(self.a, self.b, self.c, axis=1)
 
 
 class Kendalltau(Benchmark):
@@ -213,7 +213,8 @@ class DistributionsAll(Benchmark):
     slow_dists = ['nct', 'ncx2', 'argus', 'cosine', 'foldnorm', 'gausshyper',
                   'kappa4', 'invgauss', 'wald', 'vonmises_line', 'ksone',
                   'genexpon', 'exponnorm', 'recipinvgauss', 'vonmises',
-                  'foldcauchy', 'kstwo', 'levy_stable', 'skewnorm']
+                  'foldcauchy', 'kstwo', 'levy_stable', 'skewnorm',
+                  'studentized_range']
     slow_methods = ['moment']
 
     def setup(self, dist_name, method):
@@ -244,6 +245,8 @@ class DistributionsAll(Benchmark):
             if isinstance(self.dist, stats.rv_discrete):
                 raise NotImplementedError("This attribute is not a member "
                                           "of the distribution")
+            if self.dist.name in {'irwinhall'}:
+                raise NotImplementedError("Fit is unreliable.")
             # the only positional argument is the data to be fitted
             self.args = [self.dist.rvs(*dist_shapes, size=100, random_state=0, **kwds)]
         elif method == 'rvs':
@@ -351,9 +354,9 @@ class PDFPeakMemory(Benchmark):
     def setup(self, dist_name):
         # This benchmark is demanding. Skip it if the env isn't xslow.
         if not is_xslow():
-            raise NotImplementedError("skipped - enviroment is not xslow. "
-                                      "To enable this benchamark, set the "
-                                      "enviroment variable SCIPY_XSLOW=1")
+            raise NotImplementedError("skipped - environment is not xslow. "
+                                      "To enable this benchmark, set the "
+                                      "environment variable SCIPY_XSLOW=1")
 
         if dist_name in self.slow_dists:
             raise NotImplementedError("skipped - dist is too slow.")
@@ -411,7 +414,9 @@ class Distribution(Benchmark):
                 stats.beta.fit(self.x, loc=4, scale=10)
 
     # Retain old benchmark results (remove this if changing the benchmark)
-    time_distribution.version = "fb22ae5386501008d945783921fe44aef3f82c1dafc40cddfaccaeec38b792b0"
+    time_distribution.version = (
+        "fb22ae5386501008d945783921fe44aef3f82c1dafc40cddfaccaeec38b792b0"
+    )
 
 
 class DescriptiveStats(Benchmark):
@@ -543,6 +548,11 @@ class ContinuousFitAnalyticalMLEOverride(Benchmark):
         if True in nonrelevant_parameters or False not in relevant_parameters:
             raise NotImplementedError("skip non-relevant case")
 
+        # TODO: fix failing benchmarks (Aug. 2023), skipped for now
+        if ((dist_name == "pareto" and loc_fixed and scale_fixed)
+                or (dist_name == "invgauss" and loc_fixed)):
+            raise NotImplementedError("skip failing benchmark")
+
         # add fixed values if fixed in relevant_parameters to self.fixed
         # with keys from self.fnames and values in the same order as `fnames`.
         fixed_vales = self.custom_input.get(dist_name, [.834, 4.342,
@@ -606,7 +616,7 @@ class BenchQMCDiscrepancy(Benchmark):
         self.sample = sample
 
     def time_discrepancy(self, method):
-        disc = stats.qmc.discrepancy(self.sample, method=method)
+        stats.qmc.discrepancy(self.sample, method=method)
 
 
 class BenchQMCHalton(Benchmark):
@@ -642,6 +652,22 @@ class BenchQMCSobol(Benchmark):
         seq = stats.qmc.Sobol(d, scramble=False, bits=32, seed=self.rng)
         seq.random_base2(base2)
 
+class BenchPoissonDisk(Benchmark):
+    param_names = ['d', 'radius', 'ncandidates', 'n']
+    params = [
+        [1, 3, 5],
+        [0.2, 0.1, 0.05],
+        [30, 60, 120],
+        [30, 100, 300]
+    ]
+
+    def setup(self, d, radius, ncandidates, n):
+        self.rng = np.random.default_rng(168525179735951991038384544)
+
+    def time_poisson_disk(self, d, radius, ncandidates, n):
+        seq = stats.qmc.PoissonDisk(d, radius=radius, ncandidates=ncandidates,
+                                    seed=self.rng)
+        seq.random(n)
 
 class DistanceFunctions(Benchmark):
     param_names = ['n_size']
@@ -657,14 +683,12 @@ class DistanceFunctions(Benchmark):
         self.v_weights = rng.random(n_size // 2) * 10
 
     def time_energy_distance(self, n_size):
-        distance = stats.energy_distance(
-                 self.u_values, self.v_values,
-                 self.u_weights, self.v_weights)
+        stats.energy_distance(self.u_values, self.v_values,
+                              self.u_weights, self.v_weights)
 
     def time_wasserstein_distance(self, n_size):
-        distance = stats.wasserstein_distance(
-                 self.u_values, self.v_values,
-                 self.u_weights, self.v_weights)
+        stats.wasserstein_distance(self.u_values, self.v_values,
+                                   self.u_weights, self.v_weights)
 
 
 class Somersd(Benchmark):
@@ -679,7 +703,7 @@ class Somersd(Benchmark):
         self.y = rng.choice(n_size, size=n_size)
 
     def time_somersd(self, n_size):
-        res = stats.somersd(self.x, self.y)
+        stats.somersd(self.x, self.y)
 
 
 class KolmogorovSmirnov(Benchmark):
