@@ -106,7 +106,7 @@ import importlib
 import importlib.util
 import errno
 import contextlib
-from sysconfig import get_path
+import sysconfig
 import math
 import traceback
 from concurrent.futures.process import _MAX_WINDOWS_WORKERS
@@ -309,11 +309,6 @@ class Dirs:
         else:
             self.installed = self.build.parent / (self.build.stem + "-install")
 
-        if sys.platform == 'win32' and sys.version_info < (3, 10):
-            # Work around a pathlib bug; these must be absolute paths
-            self.build = Path(os.path.abspath(self.build))
-            self.installed = Path(os.path.abspath(self.installed))
-
         # relative path for site-package with py version
         # i.e. 'lib/python3.10/site-packages'
         self.site = self.get_site_packages()
@@ -331,22 +326,14 @@ class Dirs:
         return dist_packages path or site_packages path.
         """
         if sys.version_info >= (3, 12):
-            plat_path = Path(get_path('platlib'))
+            plat_path = Path(sysconfig.get_path('platlib'))
         else:
-            # distutils is required to infer meson install path
-            # for python < 3.12 in debian patched python
-            with warnings.catch_warnings():
-                warnings.filterwarnings("ignore", category=DeprecationWarning)
-                from distutils import dist
-                from distutils.command.install import INSTALL_SCHEMES
-            if 'deb_system' in INSTALL_SCHEMES:
-                # debian patched python in use
-                install_cmd = dist.Distribution().get_command_obj('install')
-                install_cmd.select_scheme('deb_system')
-                install_cmd.finalize_options()
-                plat_path = Path(install_cmd.install_platlib)
+            # infer meson install path for python < 3.12 in
+            # debian patched python
+            if 'deb_system' in sysconfig.get_scheme_names():
+                plat_path = Path(sysconfig.get_path('platlib', 'deb_system'))
             else:
-                plat_path = Path(get_path('platlib'))
+                plat_path = Path(sysconfig.get_path('platlib'))
         return self.installed / plat_path.relative_to(sys.exec_prefix)
 
 
@@ -416,6 +403,8 @@ class Build(Task):
               "build and build-install directories)."))
     debug = Option(
         ['--debug', '-d'], default=False, is_flag=True, help="Debug build")
+    release = Option(
+        ['--release', '-r'], default=False, is_flag=True, help="Release build")
     parallel = Option(
         ['--parallel', '-j'], default=None, metavar='N_JOBS',
         help=("Number of parallel jobs for building. "
@@ -486,6 +475,25 @@ class Build(Task):
                 return
         if args.werror:
             cmd += ["--werror"]
+        if args.debug or args.release:
+            if args.debug and args.release:
+                raise ValueError("Set at most one of `--debug` and `--release`!")
+            if args.debug:
+                buildtype = 'debug'
+                cflags_unwanted = ('-O1', '-O2', '-O3')
+            elif args.release:
+                buildtype = 'release'
+                cflags_unwanted = ('-O0', '-O1', '-O2')
+            cmd += [f"-Dbuildtype={buildtype}"]
+            if 'CFLAGS' in os.environ.keys():
+                # Check that CFLAGS doesn't contain something that supercedes -O0
+                # for a plain debug build (conda envs tend to set -O2)
+                cflags = os.environ['CFLAGS'].split()
+                for flag in cflags_unwanted:
+                    if flag in cflags:
+                        raise ValueError(f"A {buildtype} build isn't possible, "
+                                         f"because CFLAGS contains `{flag}`."
+                                          "Please also check CXXFLAGS and FFLAGS.")
         if args.gcov:
             cmd += ['-Db_coverage=true']
         if args.asan:
@@ -665,7 +673,7 @@ class Test(Task):
     $ python dev.py test -t scipy.optimize.tests.test_minimize_constrained
     $ python dev.py test -s cluster -m full --durations 20
     $ python dev.py test -s stats -- --tb=line  # `--` passes next args to pytest
-    $ python dev.py test -b numpy -b pytorch -s cluster
+    $ python dev.py test -b numpy -b torch -s cluster
     ```
     """
     ctx = CONTEXT
@@ -702,7 +710,7 @@ class Test(Task):
         multiple=True,
         help=(
             "Array API backend "
-            "('all', 'numpy', 'pytorch', 'cupy', 'array_api_strict', 'jax.numpy')."
+            "('all', 'numpy', 'torch', 'cupy', 'array_api_strict', 'jax.numpy')."
         )
     )
     # Argument can't have `help=`; used to consume all of `-- arg1 arg2 arg3`
@@ -714,6 +722,53 @@ class Test(Task):
         'task_dep': ['build'],
     }
 
+    @staticmethod
+    def run_lcov(dirs):
+        print("Capturing lcov info...")
+        LCOV_OUTPUT_FILE = os.path.join(dirs.build, "lcov.info")
+        LCOV_OUTPUT_DIR = os.path.join(dirs.build, "lcov")
+        BUILD_DIR = str(dirs.build)
+
+        try:
+            os.unlink(LCOV_OUTPUT_FILE)
+        except OSError:
+            pass
+        try:
+            shutil.rmtree(LCOV_OUTPUT_DIR)
+        except OSError:
+            pass
+
+        lcov_cmd = [
+            "lcov", "--capture",
+            "--directory", BUILD_DIR,
+            "--output-file", LCOV_OUTPUT_FILE,
+            "--no-external"]
+        lcov_cmd_str = " ".join(lcov_cmd)
+        emit_cmdstr(" ".join(lcov_cmd))
+        try:
+            subprocess.call(lcov_cmd)
+        except OSError as err:
+            if err.errno == errno.ENOENT:
+                print(f"Error when running '{lcov_cmd_str}': {err}\n"
+                    "You need to install LCOV (https://lcov.readthedocs.io/en/latest/) "
+                    "to capture test coverage of C/C++/Fortran code in SciPy.")
+                return False
+            raise
+
+        print("Generating lcov HTML output...")
+        genhtml_cmd = [
+            "genhtml", "-q", LCOV_OUTPUT_FILE,
+            "--output-directory", LCOV_OUTPUT_DIR,
+            "--legend", "--highlight"]
+        emit_cmdstr(genhtml_cmd)
+        ret = subprocess.call(genhtml_cmd)
+        if ret != 0:
+            print("genhtml failed!")
+        else:
+            print("HTML output generated under build/lcov/")
+
+        return ret == 0
+
     @classmethod
     def scipy_tests(cls, args, pytest_args):
         dirs = Dirs(args)
@@ -755,6 +810,22 @@ class Test(Task):
                   f"installed at:{mod_path}")
             # runner verbosity - convert bool to int
             verbose = int(args.verbose) + 1
+
+            was_built_with_gcov_flag = len(list(dirs.build.rglob("*.gcno"))) > 0
+            if was_built_with_gcov_flag:
+                config = importlib.import_module("scipy.__config__").show(mode='dicts')
+                compilers_config = config['Compilers']
+                cpp = compilers_config['c++']['name']
+                c = compilers_config['c']['name']
+                fortran = compilers_config['fortran']['name']
+                if not (c == 'gcc' and cpp == 'gcc' and fortran == 'gcc'):
+                    print("SciPy was built with --gcov flag which requires "
+                          "LCOV while running tests.\nFurther, LCOV usage "
+                          "requires GCC for C, C++ and Fortran codes in SciPy.\n"
+                          "Compilers used currently are:\n"
+                          f"  C: {c}\n  C++: {cpp}\n  Fortran: {fortran}\n"
+                          "Therefore, exiting without running tests.")
+                    exit(1) # Exit because tests will give missing symbol error
             result = runner(  # scipy._lib._testutils:PytestTester
                 args.mode,
                 verbose=verbose,
@@ -763,6 +834,12 @@ class Test(Task):
                 coverage=args.coverage,
                 tests=tests,
                 parallel=args.parallel)
+            if args.coverage and was_built_with_gcov_flag:
+                if not result:
+                    print("Tests should succeed to generate "
+                          "coverage reports using LCOV")
+                else:
+                    return cls.run_lcov(dirs)
         return result
 
     @classmethod
@@ -811,6 +888,10 @@ class SmokeDocs(Task):
         dirs.add_sys_path()
         print(f"SciPy from development installed path at: {dirs.site}")
 
+        # prevent obscure error later; cf https://github.com/numpy/numpy/pull/26691/
+        if not importlib.util.find_spec("scipy_doctest"):
+            raise ModuleNotFoundError("Please install scipy-doctest")
+
         # FIXME: support pos-args with doit
         extra_argv = list(pytest_args[:]) if pytest_args else []
         if extra_argv and extra_argv[0] == '--':
@@ -827,7 +908,9 @@ class SmokeDocs(Task):
         else:
             tests = None
 
-        # use strategy=api unless -t path/to/specific/file
+        # Request doctesting; use strategy=api unless -t path/to/specific/file
+        # also switch off assertion rewriting: not useful for doctests
+        extra_argv += ["--doctest-modules", "--assert=plain"]
         if not args.tests:
             extra_argv += ['--doctest-collect=api']
 
@@ -1078,11 +1161,11 @@ def task_check_python_h_first():
     }
 
 
-def task_unicode_check():
-    # emit_cmdstr(os.path.join('tools', 'unicode-check.py'))
+def task_check_unicode():
+    # emit_cmdstr(os.path.join('tools', 'check_unicode.py'))
     return {
-        'basename': 'unicode-check',
-        'actions': [str(Dirs().root / 'tools' / 'unicode-check.py')],
+        'basename': 'check_unicode',
+        'actions': [str(Dirs().root / 'tools' / 'check_unicode.py')],
         'doc': 'Check for disallowed Unicode characters in the SciPy Python '
                'and Cython source code.',
     }
@@ -1109,7 +1192,7 @@ class Lint:
     def run(cls, fix):
         run_doit_task({
             'lint': {'fix': fix},
-            'unicode-check': {},
+            'check-unicode': {},
             'check-testname': {},
             'check_python_h_first': {},
         })
