@@ -8,6 +8,7 @@ from datetime import date
 from docutils import nodes
 from docutils.parsers.rst import Directive
 
+from intersphinx_registry import get_intersphinx_mapping
 import matplotlib
 import matplotlib.pyplot as plt
 from numpydoc.docscrape_sphinx import SphinxDocString
@@ -26,9 +27,6 @@ old_isdesc = inspect.isdescriptor
 inspect.isdescriptor = (lambda obj: old_isdesc(obj)
                         and not isinstance(obj, ua._Function))
 
-# Currently required to build scipy.fft docs
-os.environ['_SCIPY_BUILDING_DOC'] = 'True'
-
 # -----------------------------------------------------------------------------
 # General configuration
 # -----------------------------------------------------------------------------
@@ -47,6 +45,7 @@ extensions = [
     'sphinx.ext.mathjax',
     'sphinx.ext.intersphinx',
     'numpydoc',
+    'sphinx_copybutton',
     'sphinx_design',
     'scipyoptdoc',
     'doi_role',
@@ -72,7 +71,7 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'SciPy'
-copyright = '2008-%s, The SciPy community' % date.today().year
+copyright = f'2008-{date.today().year}, The SciPy community'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
@@ -101,6 +100,9 @@ default_role = "autolink"
 # List of directories, relative to source directories, that shouldn't be searched
 # for source files.
 exclude_dirs = []
+exclude_patterns = [  # glob-style
+    "**.ipynb",
+]
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = False
@@ -133,10 +135,6 @@ nitpick_ignore = [
     ("py:class", "v, remove specified key and return the corresponding value."),
 ]
 
-exclude_patterns = [  # glob-style
-
-]
-
 # be strict about warnings in our examples, we should write clean code
 # (exceptions permitted for pedagogical purposes below)
 warnings.resetwarnings()
@@ -184,12 +182,14 @@ warnings.filterwarnings(
     message=r'There is no current event loop',
     category=DeprecationWarning,
 )
-# TODO: remove after gh-19228 resolved:
+
+# see: https://github.com/scipy/scipy/issues/22020
 warnings.filterwarnings(
     'ignore',
-    message=r'.*path is deprecated.*',
-    category=DeprecationWarning,
+    message=r'.*py:obj reference target not found: scipy.misc.*',
+    category=Warning,
 )
+
 # See https://github.com/sphinx-doc/sphinx/issues/12589
 suppress_warnings = [
     'autosummary.import_cycle',
@@ -274,18 +274,16 @@ htmlhelp_basename = 'scipy'
 
 mathjax_path = "scipy-mathjax/MathJax.js?config=scipy-mathjax"
 
+# sphinx-copybutton configurations
+copybutton_prompt_text = r">>> |\.\.\. |\$ |In \[\d*\]: | {2,5}\.{3,}: | {5,8}: "
+copybutton_prompt_is_regexp = True
+
 # -----------------------------------------------------------------------------
 # Intersphinx configuration
 # -----------------------------------------------------------------------------
-intersphinx_mapping = {
-    'python': ('https://docs.python.org/3', None),
-    'numpy': ('https://numpy.org/devdocs', None),
-    'neps': ('https://numpy.org/neps', None),
-    'matplotlib': ('https://matplotlib.org/stable', None),
-    'asv': ('https://asv.readthedocs.io/en/stable/', None),
-    'statsmodels': ('https://www.statsmodels.org/stable', None),
-}
-
+intersphinx_mapping = get_intersphinx_mapping(
+    packages={"python", "numpy", "neps", "matplotlib", "asv", "statsmodels", "mpmath"}
+)
 
 # -----------------------------------------------------------------------------
 # Numpy extensions
@@ -353,15 +351,7 @@ plot_pre_code = """
 import warnings
 for key in (
         'interp2d` is deprecated',  # Deprecation of scipy.interpolate.interp2d
-        'scipy.misc',  # scipy.misc deprecated in v1.10.0; use scipy.datasets
         '`kurtosistest` p-value may be',  # intentionally "bad" example in docstring
-        'scipy.signal.daub is deprecated',
-        'scipy.signal.qmf is deprecated',
-        'scipy.signal.cascade is deprecated',
-        'scipy.signal.morlet is deprecated',
-        'scipy.signal.morlet2 is deprecated',
-        'scipy.signal.ricker is deprecated',
-        'scipy.signal.cwt is deprecated',
         ):
     warnings.filterwarnings(action='ignore', message='.*' + key + '.*')
 
@@ -398,9 +388,21 @@ plot_rcparams = {
 # Notebook tutorials with MyST-NB
 # -----------------------------------------------------------------------------
 
-nb_execution_mode = "auto"
+nb_execution_mode = "cache"
 # Ignore notebooks generated by jupyterlite-sphinx for interactive examples.
 nb_execution_excludepatterns = ["_contents/*.ipynb"]
+# Prevent creation of transition syntax when adding footnotes
+# See https://github.com/executablebooks/MyST-Parser/issues/352
+myst_footnote_transition = False
+myst_enable_extensions = [
+    "colon_fence",
+    "dollarmath",
+    "substitution",
+]
+nb_render_markdown_format = "myst"
+render_markdown_format = "myst"
+# Fix rendering of MathJax objects in Jupyter notebooks
+myst_update_mathjax = False
 
 #------------------------------------------------------------------------------
 # Interactive examples with jupyterlite-sphinx
@@ -480,7 +482,7 @@ def linkcode_resolve(domain, info):
         lineno = None
 
     if lineno:
-        linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1)
+        linespec = f"#L{0}-L{1}".format(lineno, lineno + len(source) - 1)
     else:
         linespec = ""
 
@@ -525,8 +527,9 @@ class LegacyDirective(Directive):
             # Argument is empty; use default text
             obj = "submodule"
         text = (f"This {obj} is considered legacy and will no longer receive "
-                "updates. This could also mean it will be removed in future "
-                "SciPy versions.")
+                "updates. While we currently have no plans to remove it, "
+                "we recommend that new code uses more modern alternatives instead."
+        )
 
         try:
             self.content[0] = text+" "+self.content[0]
