@@ -9,7 +9,7 @@ from pytest import raises as assert_raises
 import scipy.fft as fft
 from scipy.conftest import array_api_compatible
 from scipy._lib._array_api import (
-    array_namespace, size, xp_assert_close, xp_assert_equal
+    array_namespace, xp_size, xp_assert_close, xp_assert_equal
 )
 
 pytestmark = [array_api_compatible, pytest.mark.usefixtures("skip_xp_backends")]
@@ -50,8 +50,8 @@ class TestFFT:
         for i in [1, 2, 16, 128, 512, 53, 149, 281, 397]:
             xp_assert_close(fft.ifft(fft.fft(x[0:i])), x[0:i])
             xp_assert_close(fft.irfft(fft.rfft(xr[0:i]), i), xr[0:i])
-    
-    @skip_xp_backends(np_only=True, reasons=['significant overhead for some backends'])
+
+    @skip_xp_backends(np_only=True, reason='significant overhead for some backends')
     def test_identity_extensive(self, xp):
         maxlen = 512
         x = xp.asarray(random(maxlen) + 1j*random(maxlen))
@@ -70,7 +70,7 @@ class TestFFT:
                         expect / xp.sqrt(xp.asarray(30, dtype=xp.float64)),)
         xp_assert_close(fft.fft(x, norm="forward"), expect / 30)
 
-    @skip_xp_backends(np_only=True, reasons=['some backends allow `n=0`'])
+    @skip_xp_backends(np_only=True, reason='some backends allow `n=0`')
     def test_fft_n(self, xp):
         x = xp.asarray([1, 2, 3], dtype=xp.complex128)
         assert_raises(ValueError, fft.fft, x, 0)
@@ -123,7 +123,7 @@ class TestFFT:
 
     def test_rfft(self, xp):
         x = xp.asarray(random(29), dtype=xp.float64)
-        for n in [size(x), 2*size(x)]:
+        for n in [xp_size(x), 2*xp_size(x)]:
             for norm in [None, "backward", "ortho", "forward"]:
                 xp_assert_close(fft.rfft(x, n=n, norm=norm),
                                 fft.fft(xp.asarray(x, dtype=xp.complex128),
@@ -285,7 +285,7 @@ class TestFFT:
         x = xp.asarray(random(30), dtype=xp.float64)
         xp_test = array_namespace(x)
         x_norm = xp_test.linalg.vector_norm(x)
-        n = size(x) * 2
+        n = xp_size(x) * 2
         func_pairs = [(fft.rfft, fft.irfft),
                       # hfft: order so the first function takes x.size samples
                       #       (necessary for comparison to x_norm above)
@@ -297,7 +297,7 @@ class TestFFT:
             if forw == fft.fft:
                 x = xp.asarray(x, dtype=xp.complex128)
                 x_norm = xp_test.linalg.vector_norm(x)
-            for n in [size(x), 2*size(x)]:
+            for n in [xp_size(x), 2*xp_size(x)]:
                 for norm in ['backward', 'ortho', 'forward']:
                     tmp = forw(x, n=n, norm=norm)
                     tmp = back(tmp, n=n, norm=norm)
@@ -333,14 +333,15 @@ class TestFFT:
 
     @pytest.mark.parametrize("dtype", ["complex64", "complex128"])
     def test_dtypes_complex(self, dtype, xp):
-        x = xp.asarray(random(30), dtype=getattr(xp, dtype))
+        rng = np.random.default_rng(1234)
+        x = xp.asarray(rng.random(30), dtype=getattr(xp, dtype))
 
         res_fft = fft.ifft(fft.fft(x))
         # Check both numerical results and exact dtype matches
         xp_assert_close(res_fft, x)
 
     @skip_xp_backends(np_only=True,
-                      reasons=['array-likes only supported for NumPy backend'])
+                      reason='array-likes only supported for NumPy backend')
     @pytest.mark.parametrize("op", [fft.fft, fft.ifft,
                                     fft.fft2, fft.ifft2,
                                     fft.fftn, fft.ifftn,
@@ -489,3 +490,13 @@ def test_non_standard_params(func, xp):
         assert_raises(ValueError, func, x, workers=2)
         # `plan` param is not tested since SciPy does not use it currently
         # but should be tested if it comes into use
+
+
+@pytest.mark.parametrize("dtype", ['float32', 'float64'])
+@pytest.mark.parametrize("func", [fft.fft, fft.ifft, fft.irfft,
+                                  fft.fftn, fft.ifftn,
+                                  fft.irfftn, fft.hfft,])
+def test_real_input(func, dtype, xp):
+    x = xp.asarray([1, 2, 3], dtype=getattr(xp, dtype))
+    # func(x) should not raise an exception
+    func(x)
