@@ -31,6 +31,7 @@ Univariate interpolation
    CubicSpline
    PPoly
    BPoly
+   FloaterHormannInterpolator
 
 
 Multivariate interpolation
@@ -68,7 +69,7 @@ Tensor product polynomials:
    :toctree: generated/
 
    NdPPoly
-
+   NdBSpline
 
 1-D Splines
 ===========
@@ -79,6 +80,10 @@ Tensor product polynomials:
    BSpline
    make_interp_spline
    make_lsq_spline
+   make_smoothing_spline
+   generate_knots
+   make_splrep
+   make_splprep
 
 Functional interface to FITPACK routines:
 
@@ -136,6 +141,15 @@ Low-level interface to FITPACK functions:
    bisplrep
    bisplev
 
+Rational Approximation
+======================
+
+.. autosummary::
+   :toctree: generated/
+
+   pade
+   AAA
+
 Additional tools
 ================
 
@@ -144,7 +158,6 @@ Additional tools
 
    lagrange
    approximate_taylor_polynomial
-   pade
 
 .. seealso::
 
@@ -180,13 +193,18 @@ from ._cubic import *
 from ._ndgriddata import *
 
 from ._bsplines import *
+from ._fitpack_repro import generate_knots, make_splrep, make_splprep
 
 from ._pade import *
 
 from ._rgi import *
 
+from ._ndbspline import NdBSpline
+
+from ._bary_rational import *
+
 # Deprecated namespaces, to be removed in v2.0.0
-from . import fitpack, fitpack2, interpolate, ndgriddata, polyint, rbf
+from . import fitpack, fitpack2, interpolate, ndgriddata, polyint, rbf, interpnd
 
 __all__ = [s for s in dir() if not s.startswith('_')]
 
