@@ -20,15 +20,17 @@ __all__ = [
 
 
 import warnings
+from threading import Lock
 
-from numpy import zeros, concatenate, ravel, diff, array, ones
+from numpy import zeros, concatenate, ravel, diff, array
 import numpy as np
 
 from . import _fitpack_impl
-from . import dfitpack
+from . import _dfitpack as dfitpack
 
 
 dfitpack_int = dfitpack.types.intvar.dtype
+FITPACK_LOCK = Lock()
 
 
 # ############### Univariate spline ####################
@@ -72,6 +74,10 @@ class UnivariateSpline:
     """
     1-D smoothing spline fit to a given set of data points.
 
+    .. legacy:: class
+
+        Specifically, we recommend using `make_splrep` instead.
+
     Fits a spline y = spl(x) of degree `k` to the provided `x`, `y` data.  `s`
     specifies the number of knots by specifying a smoothing condition.
 
@@ -122,7 +128,7 @@ class UnivariateSpline:
         * if ext=0 or 'extrapolate', return the extrapolated value.
         * if ext=1 or 'zeros', return 0
         * if ext=2 or 'raise', raise a ValueError
-        * if ext=3 of 'const', return the boundary value.
+        * if ext=3 or 'const', return the boundary value.
 
         Default is 0.
 
@@ -233,8 +239,9 @@ class UnivariateSpline:
                                                       check_finite)
 
         # _data == x,y,w,xb,xe,k,s,n,t,c,fp,fpint,nrdata,ier
-        data = dfitpack.fpcurf0(x, y, k, w=w, xb=bbox[0],
-                                xe=bbox[1], s=s)
+        with FITPACK_LOCK:
+            data = dfitpack.fpcurf0(x, y, k, w=w, xb=bbox[0],
+                                    xe=bbox[1], s=s)
         if data[-1] == 1:
             # nest too small, setting to maximum bound
             data = self._reset_nest(data)
@@ -272,7 +279,7 @@ class UnivariateSpline:
         try:
             ext = _extrap_modes[ext]
         except KeyError as e:
-            raise ValueError("Unknown extrapolation mode %s." % ext) from e
+            raise ValueError(f"Unknown extrapolation mode {ext}.") from e
 
         return x, y, w, bbox, ext
 
@@ -309,8 +316,8 @@ class UnivariateSpline:
             # error
             if ier == 1:
                 self._set_class(LSQUnivariateSpline)
-            message = _curfit_messages.get(ier, 'ier=%s' % (ier))
-            warnings.warn(message)
+            message = _curfit_messages.get(ier, f'ier={ier}')
+            warnings.warn(message, stacklevel=3)
 
     def _set_class(self, cls):
         self._spline_class = cls
@@ -333,7 +340,8 @@ class UnivariateSpline:
                                [8, 9, 11, 12])
 
         args = data[:8] + (t, c, n, fpint, nrdata, data[13])
-        data = dfitpack.fpcurf1(*args)
+        with FITPACK_LOCK:
+            data = dfitpack.fpcurf1(*args)
         return data
 
     def set_smoothing_factor(self, s):
@@ -346,10 +354,12 @@ class UnivariateSpline:
         data = self._data
         if data[6] == -1:
             warnings.warn('smoothing factor unchanged for'
-                          'LSQ spline with fixed knots')
+                          'LSQ spline with fixed knots',
+                          stacklevel=2)
             return
         args = data[:6] + (s,) + data[7:]
-        data = dfitpack.fpcurf1(*args)
+        with FITPACK_LOCK:
+            data = dfitpack.fpcurf1(*args)
         if data[-1] == 1:
             # nest too small, setting to maximum bound
             data = self._reset_nest(data)
@@ -391,8 +401,9 @@ class UnivariateSpline:
             try:
                 ext = _extrap_modes[ext]
             except KeyError as e:
-                raise ValueError("Unknown extrapolation mode %s." % ext) from e
-        return _fitpack_impl.splev(x, self._eval_args, der=nu, ext=ext)
+                raise ValueError(f"Unknown extrapolation mode {ext}.") from e
+        with FITPACK_LOCK:
+            return _fitpack_impl.splev(x, self._eval_args, der=nu, ext=ext)
 
     def get_knots(self):
         """ Return positions of interior knots of the spline.
@@ -456,7 +467,8 @@ class UnivariateSpline:
         0.0
 
         """
-        return _fitpack_impl.splint(a, b, self._eval_args)
+        with FITPACK_LOCK:
+            return _fitpack_impl.splint(a, b, self._eval_args)
 
     def derivatives(self, x):
         """ Return all derivatives of the spline at the point x.
@@ -482,7 +494,8 @@ class UnivariateSpline:
         array([2.25, 3.0, 2.0, 0])
 
         """
-        return _fitpack_impl.spalde(x, self._eval_args)
+        with FITPACK_LOCK:
+            return _fitpack_impl.spalde(x, self._eval_args)
 
     def roots(self):
         """ Return the zeros of the spline.
@@ -529,7 +542,8 @@ class UnivariateSpline:
         if k == 3:
             t = self._eval_args[0]
             mest = 3 * (len(t) - 7)
-            return _fitpack_impl.sproot(self._eval_args, mest=mest)
+            with FITPACK_LOCK:
+                return _fitpack_impl.sproot(self._eval_args, mest=mest)
         raise NotImplementedError('finding roots unsupported for '
                                   'non-cubic splines')
 
@@ -578,7 +592,8 @@ class UnivariateSpline:
         :math:`\\cos(x) = \\sin'(x)`.
 
         """
-        tck = _fitpack_impl.splder(self._eval_args, n)
+        with FITPACK_LOCK:
+            tck = _fitpack_impl.splder(self._eval_args, n)
         # if self.ext is 'const', derivative.ext will be 'zeros'
         ext = 1 if self.ext == 3 else self.ext
         return UnivariateSpline._from_tck(tck, ext=ext)
@@ -635,7 +650,8 @@ class UnivariateSpline:
         2.2572053268208538
 
         """
-        tck = _fitpack_impl.splantider(self._eval_args, n)
+        with FITPACK_LOCK:
+            tck = _fitpack_impl.splantider(self._eval_args, n)
         return UnivariateSpline._from_tck(tck, self.ext)
 
 
@@ -643,6 +659,10 @@ class InterpolatedUnivariateSpline(UnivariateSpline):
     """
     1-D interpolating spline for a given set of data points.
 
+    .. legacy:: class
+
+        Specifically, we recommend using `make_interp_spline` instead.
+
     Fits a spline y = spl(x) of degree `k` to the provided `x`, `y` data.
     Spline function passes through all provided points. Equivalent to
     `UnivariateSpline` with  `s` = 0.
@@ -736,8 +756,9 @@ class InterpolatedUnivariateSpline(UnivariateSpline):
             raise ValueError('x must be strictly increasing')
 
         # _data == x,y,w,xb,xe,k,s,n,t,c,fp,fpint,nrdata,ier
-        self._data = dfitpack.fpcurf0(x, y, k, w=w, xb=bbox[0],
-                                      xe=bbox[1], s=0)
+        with FITPACK_LOCK:
+            self._data = dfitpack.fpcurf0(x, y, k, w=w, xb=bbox[0],
+                                          xe=bbox[1], s=0)
         self._reset_class()
 
 
@@ -760,6 +781,11 @@ class LSQUnivariateSpline(UnivariateSpline):
     """
     1-D spline with explicit internal knots.
 
+    .. legacy:: class
+
+        Specifically, we recommend using `make_lsq_spline` instead.
+
+
     Fits a spline y = spl(x) of degree `k` to the provided `x`, `y` data.  `t`
     specifies the internal knots of the spline
 
@@ -889,9 +915,10 @@ class LSQUnivariateSpline(UnivariateSpline):
         if not np.all(t[k+1:n-k]-t[k:n-k-1] > 0, axis=0):
             raise ValueError('Interior knots t must satisfy '
                              'Schoenberg-Whitney conditions')
-        if not dfitpack.fpchec(x, t, k) == 0:
-            raise ValueError(_fpchec_error_string)
-        data = dfitpack.fpcurfm1(x, y, k, t, w=w, xb=xb, xe=xe)
+        with FITPACK_LOCK:
+            if not dfitpack.fpchec(x, t, k) == 0:
+                raise ValueError(_fpchec_error_string)
+            data = dfitpack.fpcurfm1(x, y, k, t, w=w, xb=xb, xe=xe)
         self._data = data[:-3] + (None, None, data[-1])
         self._reset_class()
 
@@ -1031,13 +1058,15 @@ class _BivariateSplineBase:
                 raise ValueError("y must be strictly increasing when `grid` is True")
 
             if dx or dy:
-                z, ier = dfitpack.parder(tx, ty, c, kx, ky, dx, dy, x, y)
+                with FITPACK_LOCK:
+                    z, ier = dfitpack.parder(tx, ty, c, kx, ky, dx, dy, x, y)
                 if not ier == 0:
-                    raise ValueError("Error code returned by parder: %s" % ier)
+                    raise ValueError(f"Error code returned by parder: {ier}")
             else:
-                z, ier = dfitpack.bispev(tx, ty, c, kx, ky, x, y)
+                with FITPACK_LOCK:
+                    z, ier = dfitpack.bispev(tx, ty, c, kx, ky, x, y)
                 if not ier == 0:
-                    raise ValueError("Error code returned by bispev: %s" % ier)
+                    raise ValueError(f"Error code returned by bispev: {ier}")
         else:
             # standard Numpy broadcasting
             if x.shape != y.shape:
@@ -1051,13 +1080,15 @@ class _BivariateSplineBase:
                 return np.zeros(shape, dtype=self.tck[2].dtype)
 
             if dx or dy:
-                z, ier = dfitpack.pardeu(tx, ty, c, kx, ky, dx, dy, x, y)
+                with FITPACK_LOCK:
+                    z, ier = dfitpack.pardeu(tx, ty, c, kx, ky, dx, dy, x, y)
                 if not ier == 0:
-                    raise ValueError("Error code returned by pardeu: %s" % ier)
+                    raise ValueError(f"Error code returned by pardeu: {ier}")
             else:
-                z, ier = dfitpack.bispeu(tx, ty, c, kx, ky, x, y)
+                with FITPACK_LOCK:
+                    z, ier = dfitpack.bispeu(tx, ty, c, kx, ky, x, y)
                 if not ier == 0:
-                    raise ValueError("Error code returned by bispeu: %s" % ier)
+                    raise ValueError(f"Error code returned by bispeu: {ier}")
 
             z = z.reshape(shape)
         return z
@@ -1096,7 +1127,8 @@ class _BivariateSplineBase:
                 raise ValueError("order of derivative must be less than"
                                  " degree of spline")
             tx, ty, c = self.tck[:3]
-            newc, ier = dfitpack.pardtc(tx, ty, c, kx, ky, dx, dy)
+            with FITPACK_LOCK:
+                newc, ier = dfitpack.pardtc(tx, ty, c, kx, ky, dx, dy)
             if ier != 0:
                 # This should not happen under normal conditions.
                 raise ValueError("Unexpected error code returned by"
@@ -1223,8 +1255,8 @@ class BivariateSpline(_BivariateSplineBase):
         ...     return np.exp(-np.sqrt((x / 2) ** 2 + y**2))
 
         We sample the function on a coarse grid and set up the interpolator. Note that
-        the default ``indexing="xy"`` of meshgrid would result in an unexpected (transposed)
-        result after interpolation.
+        the default ``indexing="xy"`` of meshgrid would result in an unexpected
+        (transposed) result after interpolation.
 
         >>> xarr = np.linspace(-3, 3, 21)
         >>> yarr = np.linspace(-3, 3, 21)
@@ -1270,7 +1302,8 @@ class BivariateSpline(_BivariateSplineBase):
         """
         tx, ty, c = self.tck[:3]
         kx, ky = self.degrees
-        return dfitpack.dblint(tx, ty, c, kx, ky, xa, xb, ya, yb)
+        with FITPACK_LOCK:
+            return dfitpack.dblint(tx, ty, c, kx, ky, xa, xb, ya, yb)
 
     @staticmethod
     def _validate_input(x, y, z, w, kx, ky, eps):
@@ -1300,7 +1333,7 @@ class _DerivedBivariateSpline(_BivariateSplineBase):
     -----
     The class is not meant to be instantiated directly from the data to be
     interpolated or smoothed. As a result, its ``fp`` attribute and
-    ``get_residual`` method are inherited but overriden; ``AttributeError`` is
+    ``get_residual`` method are inherited but overridden; ``AttributeError`` is
     raised when they are accessed.
 
     The other inherited attributes can be used as usual.
@@ -1313,10 +1346,10 @@ class _DerivedBivariateSpline(_BivariateSplineBase):
 
     @property
     def fp(self):
-        raise AttributeError("attribute \"fp\" %s" % self._invalid_why)
+        raise AttributeError(f"attribute \"fp\" {self._invalid_why}")
 
     def get_residual(self):
-        raise AttributeError("method \"get_residual\" %s" % self._invalid_why)
+        raise AttributeError(f"method \"get_residual\" {self._invalid_why}")
 
 
 class SmoothBivariateSpline(BivariateSpline):
@@ -1400,23 +1433,18 @@ class SmoothBivariateSpline(BivariateSpline):
             raise ValueError("s should be s >= 0.0")
 
         xb, xe, yb, ye = bbox
-        nx, tx, ny, ty, c, fp, wrk1, ier = dfitpack.surfit_smth(x, y, z, w,
-                                                                xb, xe, yb,
-                                                                ye, kx, ky,
-                                                                s=s, eps=eps,
-                                                                lwrk2=1)
-        if ier > 10:          # lwrk2 was to small, re-run
-            nx, tx, ny, ty, c, fp, wrk1, ier = dfitpack.surfit_smth(x, y, z, w,
-                                                                    xb, xe, yb,
-                                                                    ye, kx, ky,
-                                                                    s=s,
-                                                                    eps=eps,
-                                                                    lwrk2=ier)
+        with FITPACK_LOCK:
+            nx, tx, ny, ty, c, fp, wrk1, ier = dfitpack.surfit_smth(
+                x, y, z, w, xb, xe, yb, ye, kx, ky, s=s, eps=eps, lwrk2=1)
+            if ier > 10:          # lwrk2 was to small, re-run
+                nx, tx, ny, ty, c, fp, wrk1, ier = dfitpack.surfit_smth(
+                    x, y, z, w, xb, xe, yb, ye, kx, ky, s=s, eps=eps,
+                    lwrk2=ier)
         if ier in [0, -1, -2]:  # normal return
             pass
         else:
-            message = _surfit_messages.get(ier, 'ier=%s' % (ier))
-            warnings.warn(message)
+            message = _surfit_messages.get(ier, f'ier={ier}')
+            warnings.warn(message, stacklevel=2)
 
         self.fp = fp
         self.tck = tx[:nx], ty[:ny], c[:(nx-kx-1)*(ny-ky-1)]
@@ -1500,14 +1528,15 @@ class LSQBivariateSpline(BivariateSpline):
         ty1[ky+1:ny-ky-1] = ty
 
         xb, xe, yb, ye = bbox
-        tx1, ty1, c, fp, ier = dfitpack.surfit_lsq(x, y, z, nx, tx1, ny, ty1,
-                                                   w, xb, xe, yb, ye,
-                                                   kx, ky, eps, lwrk2=1)
-        if ier > 10:
-            tx1, ty1, c, fp, ier = dfitpack.surfit_lsq(x, y, z,
-                                                       nx, tx1, ny, ty1, w,
-                                                       xb, xe, yb, ye,
-                                                       kx, ky, eps, lwrk2=ier)
+        with FITPACK_LOCK:
+            tx1, ty1, c, fp, ier = dfitpack.surfit_lsq(x, y, z, nx, tx1, ny, ty1,
+                                                    w, xb, xe, yb, ye,
+                                                    kx, ky, eps, lwrk2=1)
+            if ier > 10:
+                tx1, ty1, c, fp, ier = dfitpack.surfit_lsq(x, y, z,
+                                                        nx, tx1, ny, ty1, w,
+                                                        xb, xe, yb, ye,
+                                                        kx, ky, eps, lwrk2=ier)
         if ier in [0, -1, -2]:  # normal return
             pass
         else:
@@ -1515,8 +1544,8 @@ class LSQBivariateSpline(BivariateSpline):
                 deficiency = (nx-kx-1)*(ny-ky-1)+ier
                 message = _surfit_messages.get(-3) % (deficiency)
             else:
-                message = _surfit_messages.get(ier, 'ier=%s' % (ier))
-            warnings.warn(message)
+                message = _surfit_messages.get(ier, f'ier={ier}')
+            warnings.warn(message, stacklevel=2)
         self.fp = fp
         self.tck = tx1[:nx], ty1[:ny], c
         self.degrees = kx, ky
@@ -1598,11 +1627,12 @@ class RectBivariateSpline(BivariateSpline):
 
         z = ravel(z)
         xb, xe, yb, ye = bbox
-        nx, tx, ny, ty, c, fp, ier = dfitpack.regrid_smth(x, y, z, xb, xe, yb,
-                                                          ye, kx, ky, s)
+        with FITPACK_LOCK:
+            nx, tx, ny, ty, c, fp, ier = dfitpack.regrid_smth(x, y, z, xb, xe, yb,
+                                                            ye, kx, ky, s)
 
         if ier not in [0, -1, -2]:
-            msg = _surfit_messages.get(ier, 'ier=%s' % (ier))
+            msg = _surfit_messages.get(ier, f'ier={ier}')
             raise ValueError(msg)
 
         self.fp = fp
@@ -1691,8 +1721,9 @@ class SphereBivariateSpline(_BivariateSplineBase):
         Examples
         --------
 
-        Suppose that we want to use splines to interpolate a bivariate function on a sphere.
-        The value of the function is known on a grid of longitudes and colatitudes.
+        Suppose that we want to use splines to interpolate a bivariate function on a
+        sphere. The value of the function is known on a grid of longitudes and
+        colatitudes.
 
         >>> import numpy as np
         >>> from scipy.interpolate import RectSphereBivariateSpline
@@ -1761,8 +1792,9 @@ class SphereBivariateSpline(_BivariateSplineBase):
 
         Examples
         --------
-        Suppose that we want to use splines to interpolate a bivariate function on a sphere.
-        The value of the function is known on a grid of longitudes and colatitudes.
+        Suppose that we want to use splines to interpolate a bivariate function on a
+        sphere. The value of the function is known on a grid of longitudes and
+        colatitudes.
 
         >>> import numpy as np
         >>> from scipy.interpolate import RectSphereBivariateSpline
@@ -1917,13 +1949,12 @@ class SmoothSphereBivariateSpline(SphereBivariateSpline):
         if not 0.0 < eps < 1.0:
             raise ValueError('eps should be between (0, 1)')
 
-        if np.issubclass_(w, float):
-            w = ones(len(theta)) * w
-        nt_, tt_, np_, tp_, c, fp, ier = dfitpack.spherfit_smth(theta, phi,
-                                                                r, w=w, s=s,
-                                                                eps=eps)
+        with FITPACK_LOCK:
+            nt_, tt_, np_, tp_, c, fp, ier = dfitpack.spherfit_smth(theta, phi,
+                                                                    r, w=w, s=s,
+                                                                    eps=eps)
         if ier not in [0, -1, -2]:
-            message = _spherefit_messages.get(ier, 'ier=%s' % (ier))
+            message = _spherefit_messages.get(ier, f'ier={ier}')
             raise ValueError(message)
 
         self.fp = fp
@@ -2070,16 +2101,15 @@ class LSQSphereBivariateSpline(SphereBivariateSpline):
         if not 0.0 < eps < 1.0:
             raise ValueError('eps should be between (0, 1)')
 
-        if np.issubclass_(w, float):
-            w = ones(len(theta)) * w
         nt_, np_ = 8 + len(tt), 8 + len(tp)
         tt_, tp_ = zeros((nt_,), float), zeros((np_,), float)
         tt_[4:-4], tp_[4:-4] = tt, tp
         tt_[-4:], tp_[-4:] = np.pi, 2. * np.pi
-        tt_, tp_, c, fp, ier = dfitpack.spherfit_lsq(theta, phi, r, tt_, tp_,
-                                                     w=w, eps=eps)
+        with FITPACK_LOCK:
+            tt_, tp_, c, fp, ier = dfitpack.spherfit_lsq(theta, phi, r, tt_, tp_,
+                                                        w=w, eps=eps)
         if ier > 0:
-            message = _spherefit_messages.get(ier, 'ier=%s' % (ier))
+            message = _spherefit_messages.get(ier, f'ier={ier}')
             raise ValueError(message)
 
         self.fp = fp
@@ -2115,7 +2145,7 @@ ERROR: on entry, the input data are controlled on validity
                          8<=nv<=min(nvest,mv+7)
                          v(1)<tv(5)<tv(6)<...<tv(nv-4)<v(1)+2*pi
                          the schoenberg-whitney conditions, i.e. there must be
-                         subset of grid co-ordinates uu(p) and vv(q) such that
+                         subset of grid coordinates uu(p) and vv(q) such that
                             tu(p) < uu(p) < tu(p+4) ,p=1,...,nu-4
                             (iopt(2)=1 and iopt(3)=1 also count for a uu-value
                             tv(q) < vv(q) < tv(q+4) ,q=1,...,nv-4
@@ -2339,14 +2369,15 @@ class RectSphereBivariateSpline(SphereBivariateSpline):
             raise ValueError('s should be positive')
 
         r = np.ravel(r)
-        nu, tu, nv, tv, c, fp, ier = dfitpack.regrid_smth_spher(iopt, ider,
-                                                                u.copy(),
-                                                                v.copy(),
-                                                                r.copy(),
-                                                                r0, r1, s)
+        with FITPACK_LOCK:
+            nu, tu, nv, tv, c, fp, ier = dfitpack.regrid_smth_spher(iopt, ider,
+                                                                    u.copy(),
+                                                                    v.copy(),
+                                                                    r.copy(),
+                                                                    r0, r1, s)
 
         if ier not in [0, -1, -2]:
-            msg = _spfit_messages.get(ier, 'ier=%s' % (ier))
+            msg = _spfit_messages.get(ier, f'ier={ier}')
             raise ValueError(msg)
 
         self.fp = fp
