@@ -1,15 +1,20 @@
 import os
+import sys
 
 import numpy as np
-from numpy.testing import (assert_equal, assert_allclose, assert_almost_equal,
-                           suppress_warnings)
+from numpy.testing import suppress_warnings
 from pytest import raises as assert_raises
 import pytest
+from scipy._lib._array_api import xp_assert_close, assert_almost_equal
 
-import scipy.interpolate.interpnd as interpnd
+from scipy._lib._testutils import check_free_memory
+import scipy.interpolate._interpnd as interpnd
 import scipy.spatial._qhull as qhull
 
 import pickle
+import threading
+
+_IS_32BIT = (sys.maxsize < 2**32)
 
 
 def data_file(basename):
@@ -21,8 +26,8 @@ class TestLinearNDInterpolation:
     def test_smoketest(self):
         # Test at single points
         x = np.array([(0,0), (-0.5,-0.5), (-0.5,0.5), (0.5, 0.5), (0.25, 0.3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
 
         yi = interpnd.LinearNDInterpolator(x, y)(x)
         assert_almost_equal(y, yi)
@@ -30,8 +35,8 @@ class TestLinearNDInterpolation:
     def test_smoketest_alternate(self):
         # Test at single points, alternate calling convention
         x = np.array([(0,0), (-0.5,-0.5), (-0.5,0.5), (0.5, 0.5), (0.25, 0.3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
 
         yi = interpnd.LinearNDInterpolator((x[:,0], x[:,1]), y)(x[:,0], x[:,1])
         assert_almost_equal(y, yi)
@@ -39,8 +44,8 @@ class TestLinearNDInterpolation:
     def test_complex_smoketest(self):
         # Test at single points
         x = np.array([(0,0), (-0.5,-0.5), (-0.5,0.5), (0.5, 0.5), (0.25, 0.3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
         y = y - 3j*y
 
         yi = interpnd.LinearNDInterpolator(x, y)(x)
@@ -49,20 +54,22 @@ class TestLinearNDInterpolation:
     def test_tri_input(self):
         # Test at single points
         x = np.array([(0,0), (-0.5,-0.5), (-0.5,0.5), (0.5, 0.5), (0.25, 0.3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
         y = y - 3j*y
 
         tri = qhull.Delaunay(x)
-        yi = interpnd.LinearNDInterpolator(tri, y)(x)
+        interpolator = interpnd.LinearNDInterpolator(tri, y)
+        yi = interpolator(x)
         assert_almost_equal(y, yi)
+        assert interpolator.tri is tri
 
     def test_square(self):
         # Test barycentric interpolation on a square against a manual
         # implementation
 
-        points = np.array([(0,0), (0,1), (1,1), (1,0)], dtype=np.double)
-        values = np.array([1., 2., -3., 5.], dtype=np.double)
+        points = np.array([(0,0), (0,1), (1,1), (1,0)], dtype=np.float64)
+        values = np.array([1., 2., -3., 5.], dtype=np.float64)
 
         # NB: assume triangles (0, 1, 3) and (1, 2, 3)
         #
@@ -105,8 +112,8 @@ class TestLinearNDInterpolation:
     def test_smoketest_rescale(self):
         # Test at single points
         x = np.array([(0, 0), (-5, -5), (-5, 5), (5, 5), (2.5, 3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
 
         yi = interpnd.LinearNDInterpolator(x, y, rescale=True)(x)
         assert_almost_equal(y, yi)
@@ -115,8 +122,8 @@ class TestLinearNDInterpolation:
         # Test barycentric interpolation on a rectangle with rescaling
         # agaings the same implementation without rescaling
 
-        points = np.array([(0,0), (0,100), (10,100), (10,0)], dtype=np.double)
-        values = np.array([1., 2., -3., 5.], dtype=np.double)
+        points = np.array([(0,0), (0,100), (10,100), (10,0)], dtype=np.float64)
+        values = np.array([1., 2., -3., 5.], dtype=np.float64)
 
         xx, yy = np.broadcast_arrays(np.linspace(0, 10, 14)[:,None],
                                      np.linspace(0, 100, 14)[None,:])
@@ -132,8 +139,8 @@ class TestLinearNDInterpolation:
     def test_tripoints_input_rescale(self):
         # Test at single points
         x = np.array([(0,0), (-5,-5), (-5,5), (5, 5), (2.5, 3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
         y = y - 3j*y
 
         tri = qhull.Delaunay(x)
@@ -145,8 +152,8 @@ class TestLinearNDInterpolation:
     def test_tri_input_rescale(self):
         # Test at single points
         x = np.array([(0,0), (-5,-5), (-5,5), (5, 5), (2.5, 3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
         y = y - 3j*y
 
         tri = qhull.Delaunay(x)
@@ -166,6 +173,50 @@ class TestLinearNDInterpolation:
 
         assert_almost_equal(ip(0.5, 0.5), ip2(0.5, 0.5))
 
+    @pytest.mark.slow
+    @pytest.mark.thread_unsafe
+    @pytest.mark.skipif(_IS_32BIT, reason='it fails on 32-bit')
+    def test_threading(self):
+        # This test was taken from issue 8856
+        # https://github.com/scipy/scipy/issues/8856
+        check_free_memory(10000)
+
+        r_ticks = np.arange(0, 4200, 10)
+        phi_ticks = np.arange(0, 4200, 10)
+        r_grid, phi_grid = np.meshgrid(r_ticks, phi_ticks)
+
+        def do_interp(interpolator, slice_rows, slice_cols):
+            grid_x, grid_y = np.mgrid[slice_rows, slice_cols]
+            res = interpolator((grid_x, grid_y))
+            return res
+
+        points = np.vstack((r_grid.ravel(), phi_grid.ravel())).T
+        values = (r_grid * phi_grid).ravel()
+        interpolator = interpnd.LinearNDInterpolator(points, values)
+
+        worker_thread_1 = threading.Thread(
+            target=do_interp,
+            args=(interpolator, slice(0, 2100), slice(0, 2100)))
+        worker_thread_2 = threading.Thread(
+            target=do_interp,
+            args=(interpolator, slice(2100, 4200), slice(0, 2100)))
+        worker_thread_3 = threading.Thread(
+            target=do_interp,
+            args=(interpolator, slice(0, 2100), slice(2100, 4200)))
+        worker_thread_4 = threading.Thread(
+            target=do_interp,
+            args=(interpolator, slice(2100, 4200), slice(2100, 4200)))
+
+        worker_thread_1.start()
+        worker_thread_2.start()
+        worker_thread_3.start()
+        worker_thread_4.start()
+
+        worker_thread_1.join()
+        worker_thread_2.join()
+        worker_thread_3.join()
+        worker_thread_4.join()
+
 
 class TestEstimateGradients2DGlobal:
     def test_smoketest(self):
@@ -186,8 +237,8 @@ class TestEstimateGradients2DGlobal:
             z = func(x[:,0], x[:,1])
             dz = interpnd.estimate_gradients_2d_global(tri, z, tol=1e-6)
 
-            assert_equal(dz.shape, (6, 2))
-            assert_allclose(dz, np.array(grad)[None,:] + 0*dz,
+            assert dz.shape == (6, 2)
+            xp_assert_close(dz, np.array(grad)[None,:] + 0*dz,
                             rtol=1e-5, atol=1e-5, err_msg="item %d" % j)
 
     def test_regression_2359(self):
@@ -206,8 +257,10 @@ class TestEstimateGradients2DGlobal:
 
 class TestCloughTocher2DInterpolator:
 
-    def _check_accuracy(self, func, x=None, tol=1e-6, alternate=False, rescale=False, **kw):
-        np.random.seed(1234)
+    def _check_accuracy(self, func, x=None, tol=1e-6, alternate=False,
+                        rescale=False, **kw):
+        rng = np.random.RandomState(1234)
+        # np.random.seed(1234)
         if x is None:
             x = np.array([(0, 0), (0, 1),
                           (1, 0), (1, 1), (0.25, 0.75), (0.6, 0.8),
@@ -222,7 +275,7 @@ class TestCloughTocher2DInterpolator:
                                                      func(x[:,0], x[:,1]),
                                                      tol=1e-6, rescale=rescale)
 
-        p = np.random.rand(50, 2)
+        p = rng.rand(50, 2)
 
         if not alternate:
             a = ip(p)
@@ -231,7 +284,7 @@ class TestCloughTocher2DInterpolator:
         b = func(p[:,0], p[:,1])
 
         try:
-            assert_allclose(a, b, **kw)
+            xp_assert_close(a, b, **kw)
         except AssertionError:
             print("_check_accuracy: abs(a-b):", abs(a - b))
             print("ip.grad:", ip.grad)
@@ -277,8 +330,8 @@ class TestCloughTocher2DInterpolator:
     def test_tri_input(self):
         # Test at single points
         x = np.array([(0,0), (-0.5,-0.5), (-0.5,0.5), (0.5, 0.5), (0.25, 0.3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
         y = y - 3j*y
 
         tri = qhull.Delaunay(x)
@@ -288,8 +341,8 @@ class TestCloughTocher2DInterpolator:
     def test_tri_input_rescale(self):
         # Test at single points
         x = np.array([(0,0), (-5,-5), (-5,5), (5, 5), (2.5, 3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
         y = y - 3j*y
 
         tri = qhull.Delaunay(x)
@@ -301,8 +354,8 @@ class TestCloughTocher2DInterpolator:
     def test_tripoints_input_rescale(self):
         # Test at single points
         x = np.array([(0,0), (-5,-5), (-5,5), (5, 5), (2.5, 3)],
-                     dtype=np.double)
-        y = np.arange(x.shape[0], dtype=np.double)
+                     dtype=np.float64)
+        y = np.arange(x.shape[0], dtype=np.float64)
         y = y - 3j*y
 
         tri = qhull.Delaunay(x)
@@ -310,6 +363,7 @@ class TestCloughTocher2DInterpolator:
         yi_rescale = interpnd.CloughTocher2DInterpolator(tri.points, y, rescale=True)(x)
         assert_almost_equal(yi, yi_rescale)
 
+    @pytest.mark.fail_slow(5)
     def test_dense(self):
         # Should be more accurate for dense meshes
         funcs = [
@@ -320,9 +374,9 @@ class TestCloughTocher2DInterpolator:
             lambda x, y: np.cos(2*np.pi*x)*np.sin(2*np.pi*y)
         ]
 
-        np.random.seed(4321)  # use a different seed than the check!
+        rng = np.random.RandomState(4321)  # use a different seed than the check!
         grid = np.r_[np.array([(0,0), (0,1), (1,0), (1,1)], dtype=float),
-                     np.random.rand(30*30, 2)]
+                     rng.rand(30*30, 2)]
 
         for j, func in enumerate(funcs):
             self._check_accuracy(func, x=grid, tol=1e-9, atol=5e-3, rtol=1e-2,
@@ -337,9 +391,9 @@ class TestCloughTocher2DInterpolator:
 
     def test_pickle(self):
         # Test at single points
-        np.random.seed(1234)
-        x = np.random.rand(30, 2)
-        y = np.random.rand(30) + 1j*np.random.rand(30)
+        rng = np.random.RandomState(1234)
+        x = rng.rand(30, 2)
+        y = rng.rand(30) + 1j*rng.rand(30)
 
         ip = interpnd.CloughTocher2DInterpolator(x, y)
         ip2 = pickle.loads(pickle.dumps(ip))
@@ -366,12 +420,12 @@ class TestCloughTocher2DInterpolator:
 
         v1 = ip(p1)
         v2 = ip(p2)
-        assert_allclose(v1, v2)
+        xp_assert_close(v1, v2)
 
         # ... and affine invariant
-        np.random.seed(1)
-        A = np.random.randn(2, 2)
-        b = np.random.randn(2)
+        rng = np.random.RandomState(1)
+        A = rng.randn(2, 2)
+        b = rng.randn(2)
 
         points = A.dot(points.T).T + b[None,:]
         p1 = A.dot(p1) + b
@@ -382,5 +436,5 @@ class TestCloughTocher2DInterpolator:
 
         w1 = ip(p1)
         w2 = ip(p2)
-        assert_allclose(w1, v1)
-        assert_allclose(w2, v2)
+        xp_assert_close(w1, v1)
+        xp_assert_close(w2, v2)
