@@ -31,10 +31,10 @@
 from collections.abc import Iterable
 import operator
 import warnings
-import numpy
+import numpy as np
 
 
-def _extend_mode_to_code(mode):
+def _extend_mode_to_code(mode, is_filter=False):
     """Convert an extension mode to the corresponding integer code.
     """
     if mode == 'nearest':
@@ -47,8 +47,12 @@ def _extend_mode_to_code(mode):
         return 3
     elif mode == 'constant':
         return 4
+    elif mode == 'grid-wrap' and is_filter:
+        return 1
     elif mode == 'grid-wrap':
         return 5
+    elif mode == 'grid-constant' and is_filter:
+        return 4
     elif mode == 'grid-constant':
         return 6
     else:
@@ -61,7 +65,7 @@ def _normalize_sequence(input, rank):
     check if its length is equal to the length of array.
     """
     is_str = isinstance(input, str)
-    if not is_str and isinstance(input, Iterable):
+    if not is_str and np.iterable(input):
         normalized = list(input)
         if len(normalized) != rank:
             err = "sequence argument must have length equal to input rank"
@@ -76,32 +80,37 @@ def _get_output(output, input, shape=None, complex_output=False):
         shape = input.shape
     if output is None:
         if not complex_output:
-            output = numpy.zeros(shape, dtype=input.dtype.name)
+            output = np.zeros(shape, dtype=input.dtype.name)
         else:
-            complex_type = numpy.promote_types(input.dtype, numpy.complex64)
-            output = numpy.zeros(shape, dtype=complex_type)
-    elif isinstance(output, (type, numpy.dtype)):
+            complex_type = np.promote_types(input.dtype, np.complex64)
+            output = np.zeros(shape, dtype=complex_type)
+    elif isinstance(output, (type, np.dtype)):
         # Classes (like `np.float32`) and dtypes are interpreted as dtype
-        if complex_output and numpy.dtype(output).kind != 'c':
-            warnings.warn("promoting specified output dtype to complex")
-            output = numpy.promote_types(output, numpy.complex64)
-        output = numpy.zeros(shape, dtype=output)
+        if complex_output and np.dtype(output).kind != 'c':
+            warnings.warn("promoting specified output dtype to complex", stacklevel=3)
+            output = np.promote_types(output, np.complex64)
+        output = np.zeros(shape, dtype=output)
     elif isinstance(output, str):
-        output = numpy.sctypeDict[output]
-        if complex_output and numpy.dtype(output).kind != 'c':
+        output = np.dtype(output)
+        if complex_output and output.kind != 'c':
+            raise RuntimeError("output must have complex dtype")
+        elif not issubclass(output.type, np.number):
+            raise RuntimeError("output must have numeric dtype")
+        output = np.zeros(shape, dtype=output)
+    else:
+        # output was supplied as an array
+        output = np.asarray(output)
+        if output.shape != shape:
+            raise RuntimeError("output shape not correct")
+        elif complex_output and output.dtype.kind != 'c':
             raise RuntimeError("output must have complex dtype")
-        output = numpy.zeros(shape, dtype=output)
-    elif output.shape != shape:
-        raise RuntimeError("output shape not correct")
-    elif complex_output and output.dtype.kind != 'c':
-        raise RuntimeError("output must have complex dtype")
     return output
 
 
 def _check_axes(axes, ndim):
     if axes is None:
         return tuple(range(ndim))
-    elif numpy.isscalar(axes):
+    elif np.isscalar(axes):
         axes = (operator.index(axes),)
     elif isinstance(axes, Iterable):
         for ax in axes:
@@ -115,3 +124,20 @@ def _check_axes(axes, ndim):
     if len(tuple(set(axes))) != len(axes):
         raise ValueError("axes must be unique")
     return axes
+
+def _skip_if_dtype(arg):
+    """'array or dtype' polymorphism.
+
+    Return None for np.int8, dtype('float32') or 'f' etc
+           arg for np.empty(3) etc
+    """
+    if isinstance(arg, str):
+        return None
+    if type(arg) is type:
+        return None if issubclass(arg, np.generic) else arg
+    else:
+        return None if isinstance(arg, np.dtype) else arg
+
+
+def _skip_if_int(arg):
+    return None if (arg is None or isinstance(arg, int)) else arg
