@@ -1,7 +1,7 @@
 /* Anti-Copyright
  *
- * I hereby release this code into the PUBLIC DOMAIN AS IS.  There is no
- * support, warranty, or guarantee.  I will gladly accept comments, bug 
+ * I hereby release this code into the PUBLIC DOMAIN AS IS. There is no
+ * support, warranty, or guarantee. I will gladly accept comments, bug
  * reports, and patches, however.
  *
  * Robert Kern
@@ -13,36 +13,36 @@
 #include "odrpack.h"
 
 
-void F_FUNC(dodrc,DODRC)(void (*fcn)(int *n, int *m, int *np, int *nq, int *ldn, int *ldm, 
-            int *ldnp, double *beta, double *xplusd, int *ifixb, int *ifixx, 
-            int *ldifx, int *ideval, double *f, double *fjacb, double *fjacd, 
-            int *istop), 
-           int *n, int *m, int *np, int *nq, double *beta, double *y, int *ldy,
-           double *x, int *ldx, double *we, int *ldwe, int *ld2we, double *wd,
-           int *ldwd, int *ld2wd, int *ifixb, int *ifixx, int *ldifx, int *job,
-           int *ndigit, double *taufac, double *sstol, double *partol, 
-           int *maxit, int *iprint, int *lunerr, int *lunrpt, double *stpb,
-           double *stpd, int *ldstpd, double *sclb, double *scld, int *ldscld,
-           double *work, int *lwork, int *iwork, int *liwork, int *info);
-void F_FUNC(dwinf,DWINF)(int *n, int *m, int *np, int *nq, int *ldwe, int *ld2we, int *isodr,
-        int *delta, int *eps, int *xplus, int *fn, int *sd, int *vcv, int *rvar,
-        int *wss, int *wssde, int *wssep, int *rcond, int *eta, int *olmav, 
-        int *tau, int *alpha, int *actrs, int *pnorm, int *rnors, int *prers,
-        int *partl, int *sstol, int *taufc, int *apsma, int *betao, int *betac,
-        int *betas, int *betan, int *s, int *ss, int *ssf, int *qraux, int *u,
-        int *fs, int *fjacb, int *we1, int *diff, int *delts, int *deltn, 
-        int *t, int *tt, int *omega, int *fjacd, int *wrk1, int *wrk2, 
-        int *wrk3, int *wrk4, int *wrk5, int *wrk6, int *wrk7, int *lwkmn);
-void F_FUNC(dluno,DLUNO)(int *lun, char *fn, int fnlen);
-void F_FUNC(dlunc,DLUNC)(int *lun);
+void F_FUNC(dodrc,DODRC)(void (*fcn)(F_INT *n, F_INT *m, F_INT *np, F_INT *nq, F_INT *ldn, F_INT *ldm,
+            F_INT *ldnp, double *beta, double *xplusd, F_INT *ifixb, F_INT *ifixx,
+            F_INT *ldifx, F_INT *ideval, double *f, double *fjacb, double *fjacd,
+            F_INT *istop),
+           F_INT *n, F_INT *m, F_INT *np, F_INT *nq, double *beta, double *y, F_INT *ldy,
+           double *x, F_INT *ldx, double *we, F_INT *ldwe, F_INT *ld2we, double *wd,
+           F_INT *ldwd, F_INT *ld2wd, F_INT *ifixb, F_INT *ifixx, F_INT *ldifx, F_INT *job,
+           F_INT *ndigit, double *taufac, double *sstol, double *partol,
+           F_INT *maxit, F_INT *iprF_INT, F_INT *lunerr, F_INT *lunrpt, double *stpb,
+           double *stpd, F_INT *ldstpd, double *sclb, double *scld, F_INT *ldscld,
+           double *work, F_INT *lwork, F_INT *iwork, F_INT *liwork, F_INT *info);
+void F_FUNC(dwinf,DWINF)(F_INT *n, F_INT *m, F_INT *np, F_INT *nq, F_INT *ldwe, F_INT *ld2we, F_INT *isodr,
+        F_INT *delta, F_INT *eps, F_INT *xplus, F_INT *fn, F_INT *sd, F_INT *vcv, F_INT *rvar,
+        F_INT *wss, F_INT *wssde, F_INT *wssep, F_INT *rcond, F_INT *eta, F_INT *olmav,
+        F_INT *tau, F_INT *alpha, F_INT *actrs, F_INT *pnorm, F_INT *rnors, F_INT *prers,
+        F_INT *partl, F_INT *sstol, F_INT *taufc, F_INT *apsma, F_INT *betao, F_INT *betac,
+        F_INT *betas, F_INT *betan, F_INT *s, F_INT *ss, F_INT *ssf, F_INT *qraux, F_INT *u,
+        F_INT *fs, F_INT *fjacb, F_INT *we1, F_INT *diff, F_INT *delts, F_INT *deltn,
+        F_INT *t, F_INT *tt, F_INT *omega, F_INT *fjacd, F_INT *wrk1, F_INT *wrk2,
+        F_INT *wrk3, F_INT *wrk4, F_INT *wrk5, F_INT *wrk6, F_INT *wrk7, F_INT *lwkmn);
+void F_FUNC(dluno,DLUNO)(F_INT *lun, char *fn, int fnlen);
+void F_FUNC(dlunc,DLUNC)(F_INT *lun);
 
 
 
 /* callback to pass to DODRC; calls the Python function in the global structure |odr_global| */
-void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
-                  int *ldnp, double *beta, double *xplusd, int *ifixb,
-                  int *ifixx, int *ldfix, int *ideval, double *f,
-                  double *fjacb, double *fjacd, int *istop)
+void fcn_callback(F_INT *n, F_INT *m, F_INT *np, F_INT *nq, F_INT *ldn, F_INT *ldm,
+                  F_INT *ldnp, double *beta, double *xplusd, F_INT *ifixb,
+                  F_INT *ifixx, F_INT *ldfix, F_INT *ideval, double *f,
+                  double *fjacb, double *fjacd, F_INT *istop)
 {
   PyObject *arg01, *arglist;
   PyObject *result = NULL;
@@ -50,8 +50,6 @@ void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
   PyArrayObject *pyXplusD;
   void *beta_dst;
 
-  arg01 = PyTuple_New(2);
-
   if (*m != 1)
     {
       npy_intp dim2[2];
@@ -68,21 +66,18 @@ void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
       memcpy(PyArray_DATA(pyXplusD), (void *)xplusd, (*n) * sizeof(double));
     }
 
-  PyTuple_SetItem(arg01, 0, odr_global.pyBeta);
-  Py_INCREF(odr_global.pyBeta);
-  PyTuple_SetItem(arg01, 1, (PyObject *) pyXplusD);
-  Py_INCREF((PyObject *) pyXplusD);
+  arg01 = PyTuple_Pack(2, odr_global.pyBeta, (PyObject *) pyXplusD);
+  Py_DECREF(pyXplusD);
+  if (arg01 == NULL) {
+    return;
+  }
 
   if (odr_global.extra_args != NULL)
-    {
       arglist = PySequence_Concat(arg01, odr_global.extra_args);
-    }
   else
-    {
       arglist = PySequence_Tuple(arg01);        /* make a copy */
-    }
-
   Py_DECREF(arg01);
+
   *istop = 0;
 
   beta_dst = (PyArray_DATA((PyArrayObject *) odr_global.pyBeta));
@@ -100,7 +95,7 @@ void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
           PYERR2(odr_error, "Function has not been initialized");
         }
 
-      if ((result = PyEval_CallObject(odr_global.fcn, arglist)) == NULL)
+      if ((result = PyObject_CallObject(odr_global.fcn, arglist)) == NULL)
         {
           if (PyErr_ExceptionMatches(odr_stop))
             {
@@ -136,7 +131,7 @@ void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
           PYERR2(odr_error, "Function has not been initialized");
         }
 
-      if ((result = PyEval_CallObject(odr_global.fjacb, arglist)) == NULL)
+      if ((result = PyObject_CallObject(odr_global.fjacb, arglist)) == NULL)
         {
           if (PyErr_ExceptionMatches(odr_stop))
             {
@@ -152,7 +147,7 @@ void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
       if ((result_array =
            (PyArrayObject *) PyArray_ContiguousFromObject(result,
                                                           NPY_DOUBLE, 0,
-                                                          2)) == NULL)
+                                                          3)) == NULL)
         {
           PYERR2(odr_error,
                  "Result from function call is not a proper array of floats.");
@@ -195,7 +190,7 @@ void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
           PYERR2(odr_error, "fjcad has not been initialized");
         }
 
-      if ((result = PyEval_CallObject(odr_global.fjacd, arglist)) == NULL)
+      if ((result = PyObject_CallObject(odr_global.fjacd, arglist)) == NULL)
         {
           if (PyErr_ExceptionMatches(odr_stop))
             {
@@ -211,7 +206,7 @@ void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
       if ((result_array =
            (PyArrayObject *) PyArray_ContiguousFromObject(result,
                                                           NPY_DOUBLE, 0,
-                                                          2)) == NULL)
+                                                          3)) == NULL)
         {
           PYERR2(odr_error,
                  "Result from function call is not a proper array of floats.");
@@ -255,32 +250,30 @@ void fcn_callback(int *n, int *m, int *np, int *nq, int *ldn, int *ldm,
 
   Py_DECREF(result);
   Py_DECREF(arglist);
-  Py_DECREF(pyXplusD);
 
   return;
 
 fail:
   Py_XDECREF(result);
   Py_XDECREF(arglist);
-  Py_XDECREF(pyXplusD);
   *istop = -1;
   return;
 }
 
 
 /* generates Python output from the raw output from DODRC */
-PyObject *gen_output(int n, int m, int np, int nq, int ldwe, int ld2we,
+PyObject *gen_output(F_INT n, F_INT m, F_INT np, F_INT nq, F_INT ldwe, F_INT ld2we,
                      PyArrayObject * beta, PyArrayObject * work,
-                     PyArrayObject * iwork, int isodr, int info,
+                     PyArrayObject * iwork, F_INT isodr, F_INT info,
                      int full_output)
 {
   PyArrayObject *sd_beta, *cov_beta;
 
-  int delta, eps, xplus, fn, sd, vcv, rvar, wss, wssde, wssep, rcond;
-  int eta, olmav, tau, alpha, actrs, pnorm, rnors, prers, partl, sstol;
-  int taufc, apsma, betao, betac, betas, betan, s, ss, ssf, qraux, u;
-  int fs, fjacb, we1, diff, delts, deltn, t, tt, omega, fjacd;
-  int wrk1, wrk2, wrk3, wrk4, wrk5, wrk6, wrk7, lwkmn;
+  F_INT delta, eps, xplus, fn, sd, vcv, rvar, wss, wssde, wssep, rcond;
+  F_INT eta, olmav, tau, alpha, actrs, pnorm, rnors, prers, partl, sstol;
+  F_INT taufc, apsma, betao, betac, betas, betan, s, ss, ssf, qraux, u;
+  F_INT fs, fjacb, we1, diff, delts, deltn, t, tt, omega, fjacd;
+  F_INT wrk1, wrk2, wrk3, wrk4, wrk5, wrk6, wrk7, lwkmn;
 
   PyObject *retobj;
 
@@ -383,8 +376,20 @@ PyObject *gen_output(int n, int m, int np, int nq, int ldwe, int ld2we,
 
       work_ind =
         Py_BuildValue
-        ("{s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i,s:i}",
-         "delta", delta, "eps", eps, "xplus", xplus, "fn", fn, "sd", sd, "sd",
+          (("{s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT ",s:" F_INT_PYFMT
+            ",s:" F_INT_PYFMT "}"),
+         "delta", delta, "eps", eps, "xplus", xplus, "fn", fn, "sd", sd, "vcv",
          vcv, "rvar", rvar, "wss", wss, "wssde", wssde, "wssep", wssep,
          "rcond", rcond, "eta", eta, "olmav", olmav, "tau", tau, "alpha",
          alpha, "actrs", actrs, "pnorm", pnorm, "rnors", rnors, "prers",
@@ -446,7 +451,7 @@ PyObject *gen_output(int n, int m, int np, int nq, int ldwe, int ld2we,
 
       retobj =
         Py_BuildValue
-        ("OOO{s:O,s:O,s:O,s:O,s:d,s:d,s:d,s:d,s:d,s:d,s:O,s:O,s:O,s:i}",
+         (("OOO{s:O,s:O,s:O,s:O,s:d,s:d,s:d,s:d,s:d,s:d,s:O,s:O,s:O,s:" F_INT_PYFMT "}"),
          PyArray_Return(beta), PyArray_Return(sd_beta),
          PyArray_Return(cov_beta), "delta", PyArray_Return(deltaA), "eps",
          PyArray_Return(epsA), "xplus", PyArray_Return(xplusA), "y",
@@ -473,7 +478,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
   PyObject *fjacd = NULL, *pifixb = NULL, *pifixx = NULL;
   PyObject *pstpb = NULL, *pstpd = NULL, *psclb = NULL, *pscld = NULL;
   PyObject *pwork = NULL, *piwork = NULL, *extra_args = NULL;
-  int job = 0, ndigit = 0, maxit = -1, iprint = 0;
+  F_INT job = 0, ndigit = 0, maxit = -1, iprint = 0;
   int full_output = 0;
   double taufac = 0.0, sstol = -1.0, partol = -1.0;
   char *errfile = NULL, *rptfile = NULL;
@@ -482,23 +487,25 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
   PyArrayObject *ifixb = NULL, *ifixx = NULL;
   PyArrayObject *stpb = NULL, *stpd = NULL, *sclb = NULL, *scld = NULL;
   PyArrayObject *work = NULL, *iwork = NULL;
-  int n, m, np, nq, ldy, ldx, ldwe, ld2we, ldwd, ld2wd, ldifx;
-  int lunerr = -1, lunrpt = -1, ldstpd, ldscld, lwork, liwork, info = 0;
+  F_INT n, m, np, nq, ldy, ldx, ldwe, ld2we, ldwd, ld2wd, ldifx;
+  F_INT lunerr = -1, lunrpt = -1, ldstpd, ldscld, lwork, liwork, info = 0;
   static char *kw_list[] = { "fcn", "initbeta", "y", "x", "we", "wd", "fjacb",
     "fjacd", "extra_args", "ifixb", "ifixx", "job", "iprint", "errfile",
     "rptfile", "ndigit", "taufac", "sstol", "partol",
     "maxit", "stpb", "stpd", "sclb", "scld", "work",
     "iwork", "full_output", NULL
   };
-  int isodr = 1;
+  F_INT isodr = 1;
   PyObject *result;
   npy_intp dim1[1], dim2[2], dim3[3];
-  int implicit;                 /* flag for implicit model */
+  F_INT implicit;                 /* flag for implicit model */
 
 
   if (kwds == NULL)
     {
-      if (!PyArg_ParseTuple(args, "OOOO|OOOOOOOiiz#z#idddiOOOOOOi:odr",
+        if (!PyArg_ParseTuple(args, ("OOOO|OOOOOOO" F_INT_PYFMT F_INT_PYFMT
+                                     "z#z#" F_INT_PYFMT "ddd" F_INT_PYFMT
+                                     "OOOOOOi:odr"),
                             &fcn, &initbeta, &py, &px, &pwe, &pwd,
                             &fjacb, &fjacd, &extra_args, &pifixb, &pifixx,
                             &job, &iprint, &errfile, &lerrfile, &rptfile,
@@ -512,7 +519,9 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
   else
     {
       if (!PyArg_ParseTupleAndKeywords(args, kwds,
-                                       "OOOO|OOOOOOOiiz#z#idddiOOOOOOi:odr",
+                                       ("OOOO|OOOOOOO" F_INT_PYFMT "" F_INT_PYFMT
+                                        "z#z#" F_INT_PYFMT "ddd" F_INT_PYFMT
+                                        "OOOOOOi:odr"),
                                        kw_list, &fcn, &initbeta, &py, &px,
                                        &pwe, &pwd, &fjacb, &fjacd,
                                        &extra_args, &pifixb, &pifixx, &job,
@@ -536,21 +545,10 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
     {
       PYERR(PyExc_TypeError, "initbeta must be a sequence");
     }
-  if (!PySequence_Check(py))
+  if (!PySequence_Check(py) && !PyNumber_Check(py))
     {
-      /* Checking whether py is an int 
-       *
-       * XXX: PyInt_Check for np.int32 instances does not work on python 2.6 -
-       * we should fix this in numpy, workaround by trying to cast to an int
-       * for now */
-      long val;
-
-      PyErr_Clear();
-      val = PyInt_AsLong(py);
-      if (val == -1 && PyErr_Occurred()) {
-        PYERR(PyExc_TypeError,
-              "y must be a sequence or integer (if model is implicit)");
-      }
+      PYERR(PyExc_TypeError,
+            "y must be a sequence or integer (if model is implicit)");
     }
   if (!PySequence_Check(px))
     {
@@ -651,7 +649,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
   else
     {                           /* we *do* have an implicit model */
       ldy = 1;
-      nq = (int)PyInt_AsLong(py);
+      nq = (F_INT)PyLong_AsLong(py);
       dim1[0] = 1;
 
       /* initialize y to a dummy array; never referenced */
@@ -739,7 +737,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
         }
       else if (PyArray_NDIM(we) == 1 && PyArray_DIMS(we)[0] == nq)
         {
-          /* we is a rank-1 array with diagonal weightings to be broadcast 
+          /* we is a rank-1 array with diagonal weightings to be broadcast
            * to all observations */
           ldwe = 1;
           ld2we = 1;
@@ -747,7 +745,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
       else if (PyArray_NDIM(we) == 3 && PyArray_DIMS(we)[0] == nq
                && PyArray_DIMS(we)[1] == nq && PyArray_DIMS(we)[2] == 1)
         {
-          /* we is a rank-3 array with the covariant weightings 
+          /* we is a rank-3 array with the covariant weightings
              to be broadcast to all observations */
           ldwe = 1;
           ld2we = nq;
@@ -755,7 +753,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
       else if (PyArray_NDIM(we) == 2 && PyArray_DIMS(we)[0] == nq
                && PyArray_DIMS(we)[1] == nq)
         {
-          /* we is a rank-2 array with the full covariant weightings 
+          /* we is a rank-2 array with the full covariant weightings
              to be broadcast to all observations */
           ldwe = 1;
           ld2we = nq;
@@ -764,7 +762,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
       else if (PyArray_NDIM(we) == 2 && PyArray_DIMS(we)[0] == nq
                && PyArray_DIMS(we)[1] == n)
         {
-          /* we is a rank-2 array with the diagonal elements of the 
+          /* we is a rank-2 array with the diagonal elements of the
              covariant weightings for each observation */
           ldwe = n;
           ld2we = 1;
@@ -828,7 +826,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
         }
       else if (PyArray_NDIM(wd) == 1 && PyArray_DIMS(wd)[0] == m)
         {
-          /* wd is a rank-1 array with diagonal weightings to be broadcast 
+          /* wd is a rank-1 array with diagonal weightings to be broadcast
            * to all observations */
           ldwd = 1;
           ld2wd = 1;
@@ -837,7 +835,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
       else if (PyArray_NDIM(wd) == 3 && PyArray_DIMS(wd)[0] == m
                && PyArray_DIMS(wd)[1] == m && PyArray_DIMS(wd)[2] == 1)
         {
-          /* wd is a rank-3 array with the covariant wdightings 
+          /* wd is a rank-3 array with the covariant wdightings
              to be broadcast to all observations */
           ldwd = 1;
           ld2wd = m;
@@ -845,7 +843,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
       else if (PyArray_NDIM(wd) == 2 && PyArray_DIMS(wd)[0] == m
                && PyArray_DIMS(wd)[1] == m)
         {
-          /* wd is a rank-2 array with the full covariant weightings 
+          /* wd is a rank-2 array with the full covariant weightings
              to be broadcast to all observations */
           ldwd = 1;
           ld2wd = m;
@@ -854,7 +852,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
       else if (PyArray_NDIM(wd) == 2 && PyArray_DIMS(wd)[0] == m
                && PyArray_DIMS(wd)[1] == n)
         {
-          /* wd is a rank-2 array with the diagonal elements of the 
+          /* wd is a rank-2 array with the diagonal elements of the
              covariant weightings for each observation */
           ldwd = n;
           ld2wd = 1;
@@ -878,15 +876,15 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
   if (pifixb == NULL)
     {
       dim1[0] = np;
-      ifixb = (PyArrayObject *) PyArray_SimpleNew(1, dim1, NPY_INT);
-      *(int *)(PyArray_DATA(ifixb)) = -1;      /* set first element negative */
+      ifixb = (PyArrayObject *) PyArray_SimpleNew(1, dim1, F_INT_NPY);
+      *(F_INT *)(PyArray_DATA(ifixb)) = -1;      /* set first element negative */
     }
   else
     {
       /* pifixb is a sequence as checked before */
 
       if ((ifixb =
-           (PyArrayObject *) PyArray_CopyFromObject(pifixb, NPY_INT, 1,
+           (PyArrayObject *) PyArray_CopyFromObject(pifixb, F_INT_NPY, 1,
                                                     1)) == NULL)
         {
           PYERR(PyExc_ValueError,
@@ -904,8 +902,8 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
     {
       dim2[0] = m;
       dim2[1] = 1;
-      ifixx = (PyArrayObject *) PyArray_SimpleNew(2, dim2, NPY_INT);
-      *(int *)(PyArray_DATA(ifixx)) = -1;      /* set first element negative */
+      ifixx = (PyArrayObject *) PyArray_SimpleNew(2, dim2, F_INT_NPY);
+      *(F_INT *)(PyArray_DATA(ifixx)) = -1;      /* set first element negative */
       ldifx = 1;
     }
   else
@@ -913,7 +911,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
       /* pifixx is a sequence as checked before */
 
       if ((ifixx =
-           (PyArrayObject *) PyArray_CopyFromObject(pifixx, NPY_INT, 1,
+           (PyArrayObject *) PyArray_CopyFromObject(pifixx, F_INT_NPY, 1,
                                                     2)) == NULL)
         {
           PYERR(PyExc_ValueError,
@@ -1113,7 +1111,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
         }
       if (PyArray_DIMS(work)[0] < lwork)
         {
-            printf("%ld %d\n", PyArray_DIMS(work)[0], lwork);
+          printf("%lld %lld\n", (long long)PyArray_DIMS(work)[0], (long long)lwork);
           PYERR(PyExc_ValueError, "work is too small");
         }
     }
@@ -1127,7 +1125,7 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
   if (piwork != NULL)
     {
       if ((iwork =
-           (PyArrayObject *) PyArray_CopyFromObject(piwork, NPY_INT, 1,
+           (PyArrayObject *) PyArray_CopyFromObject(piwork, F_INT_NPY, 1,
                                                     1)) == NULL)
         {
           PYERR(PyExc_ValueError,
@@ -1143,10 +1141,10 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
     {
       /* initialize our own iwork array */
       dim1[0] = liwork;
-      iwork = (PyArrayObject *) PyArray_SimpleNew(1, dim1, NPY_INT);
+      iwork = (PyArrayObject *) PyArray_SimpleNew(1, dim1, F_INT_NPY);
     }                           /* iwork */
 
-  /* check if what JOB requests can be done with what the user has 
+  /* check if what JOB requests can be done with what the user has
      input into the function */
 
   if ((job / 10) % 10 >= 2)
@@ -1176,12 +1174,12 @@ PyObject *odr(PyObject * self, PyObject * args, PyObject * kwds)
          (double *)(PyArray_DATA(y)), &ldy, (double *)(PyArray_DATA(x)), &ldx,
          (double *)(PyArray_DATA(we)), &ldwe, &ld2we,
          (double *)(PyArray_DATA(wd)), &ldwd, &ld2wd,
-         (int *)(PyArray_DATA(ifixb)), (int *)(PyArray_DATA(ifixx)), &ldifx,
+         (F_INT *)(PyArray_DATA(ifixb)), (F_INT *)(PyArray_DATA(ifixx)), &ldifx,
          &job, &ndigit, &taufac, &sstol, &partol, &maxit,
          &iprint, &lunerr, &lunrpt,
          (double *)(PyArray_DATA(stpb)), (double *)(PyArray_DATA(stpd)), &ldstpd,
          (double *)(PyArray_DATA(sclb)), (double *)(PyArray_DATA(scld)), &ldscld,
-         (double *)(PyArray_DATA(work)), &lwork, (int *)(PyArray_DATA(iwork)), &liwork,
+         (double *)(PyArray_DATA(work)), &lwork, (F_INT *)(PyArray_DATA(iwork)), &liwork,
          &info);
 
   result = gen_output(n, m, np, nq, ldwe, ld2we,
@@ -1276,7 +1274,6 @@ static PyMethodDef methods[] = {
   {NULL, NULL},
 };
 
-#if PY_VERSION_HEX >= 0x03000000
 static struct PyModuleDef moduledef = {
     PyModuleDef_HEAD_INIT,
     "_odrpack",
@@ -1289,18 +1286,20 @@ static struct PyModuleDef moduledef = {
     NULL
 };
 
-PyObject *PyInit___odrpack(void)
+PyMODINIT_FUNC
+PyInit___odrpack(void)
 {
-    PyObject *m;
+    PyObject *module;
+
     import_array();
-    m = PyModule_Create(&moduledef);
-    return m;
-}
-#else
-PyMODINIT_FUNC init__odrpack(void)
-{
-    PyObject *m;
-    import_array();
-    m = Py_InitModule("__odrpack", methods);
-}
+    module = PyModule_Create(&moduledef);
+    if (module == NULL) {
+        return module;
+    }
+
+#if Py_GIL_DISABLED
+    PyUnstable_Module_SetGIL(module, Py_MOD_GIL_NOT_USED);
 #endif
+
+    return module;
+}
