@@ -4,8 +4,7 @@ from ._hessian_update_strategy import BFGS
 from ._differentiable_functions import (
     VectorFunction, LinearVectorFunction, IdentityVectorFunction)
 from ._optimize import OptimizeWarning
-from warnings import warn, catch_warnings, simplefilter
-from numpy.testing import suppress_warnings
+from warnings import warn, catch_warnings, simplefilter, filterwarnings
 from scipy.sparse import issparse
 
 
@@ -47,8 +46,10 @@ class NonlinearConstraint:
         where element (i, j) is the partial derivative of f[i] with
         respect to x[j]).  The keywords {'2-point', '3-point',
         'cs'} select a finite difference scheme for the numerical estimation.
-        A callable must have the following signature:
-        ``jac(x) -> {ndarray, sparse matrix}, shape (m, n)``.
+        A callable must have the following signature::
+
+            jac(x) -> {ndarray, sparse matrix}, shape (m, n)
+
         Default is '2-point'.
     hess : {callable, '2-point', '3-point', 'cs', HessianUpdateStrategy, None}, optional
         Method for computing the Hessian matrix. The keywords
@@ -57,8 +58,8 @@ class NonlinearConstraint:
         `HessianUpdateStrategy` interface can be used to approximate the
         Hessian. Currently available implementations are:
 
-            - `BFGS` (default option)
-            - `SR1`
+        - `BFGS` (default option)
+        - `SR1`
 
         A callable must return the Hessian matrix of ``dot(fun, v)`` and
         must have the following signature:
@@ -104,9 +105,11 @@ class NonlinearConstraint:
     >>> nlc = NonlinearConstraint(con, -np.inf, 1.9)
 
     """
-    def __init__(self, fun, lb, ub, jac='2-point', hess=BFGS(),
+    def __init__(self, fun, lb, ub, jac='2-point', hess=None,
                  keep_feasible=False, finite_diff_rel_step=None,
                  finite_diff_jac_sparsity=None):
+        if hess is None:
+            hess = BFGS()
         self.fun = fun
         self.lb = lb
         self.ub = ub
@@ -386,8 +389,12 @@ class PreparedConstraint:
             How much the constraint is exceeded by, for each of the
             constraints specified by `PreparedConstraint.fun`.
         """
-        with suppress_warnings() as sup:
-            sup.filter(UserWarning)
+        with catch_warnings():
+            # Ignore the following warning, it's not important when
+            # figuring out total violation
+            # UserWarning: delta_grad == 0.0. Check if the approximated
+            # function is linear
+            filterwarnings("ignore", "delta_grad", UserWarning)
             ev = self.fun.fun(np.asarray(x))
 
         excess_lb = np.maximum(self.bounds[0] - ev, 0)
@@ -456,7 +463,8 @@ def new_constraint_to_old(con, x0):
                 con.keep_feasible):
             warn("Constraint options `finite_diff_jac_sparsity`, "
                  "`finite_diff_rel_step`, `keep_feasible`, and `hess`"
-                 "are ignored by this method.", OptimizeWarning)
+                 "are ignored by this method.",
+                 OptimizeWarning, stacklevel=3)
 
         fun = con.fun
         if callable(con.jac):
@@ -466,8 +474,8 @@ def new_constraint_to_old(con, x0):
 
     else:  # LinearConstraint
         if np.any(con.keep_feasible):
-            warn("Constraint option `keep_feasible` is ignored by this "
-                 "method.", OptimizeWarning)
+            warn("Constraint option `keep_feasible` is ignored by this method.",
+                 OptimizeWarning, stacklevel=3)
 
         A = con.A
         if issparse(A):
@@ -489,7 +497,8 @@ def new_constraint_to_old(con, x0):
 
     if np.any(i_unbounded):
         warn("At least one constraint is unbounded above and below. Such "
-             "constraints are ignored.", OptimizeWarning)
+             "constraints are ignored.",
+             OptimizeWarning, stacklevel=3)
 
     ceq = []
     if np.any(i_eq):
@@ -537,7 +546,8 @@ def new_constraint_to_old(con, x0):
         warn("Equality and inequality constraints are specified in the same "
              "element of the constraint list. For efficient use with this "
              "method, equality and inequality constraints should be specified "
-             "in separate elements of the constraint list. ", OptimizeWarning)
+             "in separate elements of the constraint list. ",
+             OptimizeWarning, stacklevel=3)
     return old_constraints
 
 
@@ -558,7 +568,7 @@ def old_constraint_to_new(ic, con):
         raise TypeError("Constraint's type must be a string.") from e
     else:
         if ctype not in ['eq', 'ineq']:
-            raise ValueError("Unknown constraint type '%s'." % con['type'])
+            raise ValueError(f"Unknown constraint type '{con['type']}'.")
     if 'fun' not in con:
         raise ValueError('Constraint %d has no function defined.' % ic)
 
