@@ -4,6 +4,7 @@ from numpy.linalg import norm
 from scipy.sparse import issparse, csr_matrix
 from scipy.sparse.linalg import LinearOperator, lsmr
 from scipy.optimize import OptimizeResult
+from scipy.optimize._minimize import Bounds
 
 from .common import in_bounds, compute_grad
 from .trf_linear import trf_linear
@@ -11,7 +12,9 @@ from .bvls import bvls
 
 
 def prepare_bounds(bounds, n):
-    lb, ub = [np.asarray(b, dtype=float) for b in bounds]
+    if len(bounds) != 2:
+        raise ValueError("`bounds` must contain 2 elements.")
+    lb, ub = (np.asarray(b, dtype=float) for b in bounds)
 
     if lb.ndim == 0:
         lb = np.resize(lb, n)
@@ -51,22 +54,28 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
         Design matrix. Can be `scipy.sparse.linalg.LinearOperator`.
     b : array_like, shape (m,)
         Target vector.
-    bounds : 2-tuple of array_like, optional
-        Lower and upper bounds on independent variables. Defaults to no bounds.
-        Each array must have shape (n,) or be a scalar, in the latter
-        case a bound will be the same for all variables. Use ``np.inf`` with
-        an appropriate sign to disable bounds on all or some variables.
+    bounds : 2-tuple of array_like or `Bounds`, optional
+        Lower and upper bounds on parameters. Defaults to no bounds.
+        There are two ways to specify the bounds:
+
+        - Instance of `Bounds` class.
+        - 2-tuple of array_like: Each element of the tuple must be either
+          an array with the length equal to the number of parameters, or a
+          scalar (in which case the bound is taken to be the same for all
+          parameters). Use ``np.inf`` with an appropriate sign to disable
+          bounds on all or some parameters.
+
     method : 'trf' or 'bvls', optional
         Method to perform minimization.
 
-            * 'trf' : Trust Region Reflective algorithm adapted for a linear
-              least-squares problem. This is an interior-point-like method
-              and the required number of iterations is weakly correlated with
-              the number of variables.
-            * 'bvls' : Bounded-variable least-squares algorithm. This is
-              an active set method, which requires the number of iterations
-              comparable to the number of variables. Can't be used when `A` is
-              sparse or LinearOperator.
+        * 'trf' : Trust Region Reflective algorithm adapted for a linear
+          least-squares problem. This is an interior-point-like method
+          and the required number of iterations is weakly correlated with
+          the number of variables.
+        * 'bvls' : Bounded-variable least-squares algorithm. This is
+          an active set method, which requires the number of iterations
+          comparable to the number of variables. Can't be used when `A` is
+          sparse or LinearOperator.
 
         Default is 'trf'.
     tol : float, optional
@@ -74,21 +83,21 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
         of the cost function is less than `tol` on the last iteration.
         Additionally, the first-order optimality measure is considered:
 
-            * ``method='trf'`` terminates if the uniform norm of the gradient,
-              scaled to account for the presence of the bounds, is less than
-              `tol`.
-            * ``method='bvls'`` terminates if Karush-Kuhn-Tucker conditions
-              are satisfied within `tol` tolerance.
+        * ``method='trf'`` terminates if the uniform norm of the gradient,
+          scaled to account for the presence of the bounds, is less than
+          `tol`.
+        * ``method='bvls'`` terminates if Karush-Kuhn-Tucker conditions
+          are satisfied within `tol` tolerance.
 
     lsq_solver : {None, 'exact', 'lsmr'}, optional
         Method of solving unbounded least-squares problems throughout
         iterations:
 
-            * 'exact' : Use dense QR or SVD decomposition approach. Can't be
-              used when `A` is sparse or LinearOperator.
-            * 'lsmr' : Use `scipy.sparse.linalg.lsmr` iterative procedure
-              which requires only matrix-vector product evaluations. Can't
-              be used with ``method='bvls'``.
+        * 'exact' : Use dense QR or SVD decomposition approach. Can't be
+          used when `A` is sparse or LinearOperator.
+        * 'lsmr' : Use `scipy.sparse.linalg.lsmr` iterative procedure
+          which requires only matrix-vector product evaluations. Can't
+          be used with ``method='bvls'``.
 
         If None (default), the solver is chosen based on type of `A`.
     lsmr_tol : None, float or 'auto', optional
@@ -104,9 +113,10 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
     verbose : {0, 1, 2}, optional
         Level of algorithm's verbosity:
 
-            * 0 : work silently (default).
-            * 1 : display a termination report.
-            * 2 : display progress during iterations.
+        * 0 : work silently (default).
+        * 1 : display a termination report.
+        * 2 : display progress during iterations.
+
     lsmr_maxiter : None or int, optional
         Maximum number of iterations for the lsmr least squares solver,
         if it is used (by setting ``lsq_solver='lsmr'``). If None (default), it
@@ -130,9 +140,9 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
         Each component shows whether a corresponding constraint is active
         (that is, whether a variable is at the bound):
 
-            *  0 : a constraint is not active.
-            * -1 : a lower bound is active.
-            *  1 : an upper bound is active.
+        *  0 : a constraint is not active.
+        * -1 : a lower bound is active.
+        *  1 : an upper bound is active.
 
         Might be somewhat arbitrary for the `trf` method as it generates a
         sequence of strictly feasible iterates and active_mask is determined
@@ -157,12 +167,12 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
     status : int
         Reason for algorithm termination:
 
-            * -1 : the algorithm was not able to make progress on the last
-              iteration.
-            *  0 : the maximum number of iterations is exceeded.
-            *  1 : the first-order optimality measure is less than `tol`.
-            *  2 : the relative change of the cost function is less than `tol`.
-            *  3 : the unconstrained solution is optimal.
+        * -1 : the algorithm was not able to make progress on the last
+          iteration.
+        *  0 : the maximum number of iterations is exceeded.
+        *  1 : the first-order optimality measure is less than `tol`.
+        *  2 : the relative change of the cost function is less than `tol`.
+        *  3 : the unconstrained solution is optimal.
 
     message : str
         Verbal description of the termination reason.
@@ -215,12 +225,13 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
     In this example, a problem with a large sparse matrix and bounds on the
     variables is solved.
 
+    >>> import numpy as np
     >>> from scipy.sparse import rand
     >>> from scipy.optimize import lsq_linear
     >>> rng = np.random.default_rng()
     ...
-    >>> m = 20000
-    >>> n = 10000
+    >>> m = 2000
+    >>> n = 1000
     ...
     >>> A = rand(m, n, density=1e-4, random_state=rng)
     >>> b = rng.standard_normal(m)
@@ -229,10 +240,9 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
     >>> ub = lb + 1
     ...
     >>> res = lsq_linear(A, b, bounds=(lb, ub), lsmr_tol='auto', verbose=1)
-    # may vary
     The relative change of the cost function is less than `tol`.
-    Number of iterations 16, initial cost 1.5039e+04, final cost 1.1112e+04,
-    first-order optimality 4.66e-08.
+    Number of iterations 10, initial cost 1.0070e+03, final cost 9.6602e+02,
+    first-order optimality 2.21e-09.        # may vary
     """
     if method not in ['trf', 'bvls']:
         raise ValueError("`method` must be 'trf' or 'bvls'")
@@ -269,9 +279,6 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
     if len(A.shape) != 2:  # No ndim for LinearOperator.
         raise ValueError("`A` must have at most 2 dimensions.")
 
-    if len(bounds) != 2:
-        raise ValueError("`bounds` must contain 2 elements.")
-
     if max_iter is not None and max_iter <= 0:
         raise ValueError("`max_iter` must be None or positive integer.")
 
@@ -284,7 +291,11 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
     if b.size != m:
         raise ValueError("Inconsistent shapes between `A` and `b`.")
 
-    lb, ub = prepare_bounds(bounds, n)
+    if isinstance(bounds, Bounds):
+        lb = bounds.lb
+        ub = bounds.ub
+    else:
+        lb, ub = prepare_bounds(bounds, n)
 
     if lb.shape != (n,) and ub.shape != (n,):
         raise ValueError("Bounds have wrong shape.")
@@ -320,8 +331,7 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
 
         if verbose > 0:
             print(termination_message)
-            print("Final cost {0:.4e}, first-order optimality {1:.2e}"
-                  .format(cost, g_norm))
+            print(f"Final cost {cost:.4e}, first-order optimality {g_norm:.2e}")
 
         return OptimizeResult(
             x=x_lsq, fun=r, cost=cost, optimality=g_norm,
@@ -341,9 +351,10 @@ def lsq_linear(A, b, bounds=(-np.inf, np.inf), method='trf', tol=1e-10,
 
     if verbose > 0:
         print(res.message)
-        print("Number of iterations {0}, initial cost {1:.4e}, "
-              "final cost {2:.4e}, first-order optimality {3:.2e}."
-              .format(res.nit, res.initial_cost, res.cost, res.optimality))
+        print(
+            f"Number of iterations {res.nit}, initial cost {res.initial_cost:.4e}, "
+            f"final cost {res.cost:.4e}, first-order optimality {res.optimality:.2e}."
+        )
 
     del res.initial_cost
 
