@@ -1,7 +1,6 @@
 import logging
 import sys
 
-import numpy
 import numpy as np
 import time
 from multiprocessing import Pool
@@ -27,7 +26,7 @@ class StructTestFunction:
 def wrap_constraints(g):
     cons = []
     if g is not None:
-        if (type(g) is not tuple) and (type(g) is not list):
+        if not isinstance(g, (tuple, list)):
             g = (g,)
         else:
             pass
@@ -45,7 +44,7 @@ class StructTest1(StructTestFunction):
         return x[0] ** 2 + x[1] ** 2
 
     def g(x):
-        return -(numpy.sum(x, axis=0) - 6.0)
+        return -(np.sum(x, axis=0) - 6.0)
 
     cons = wrap_constraints(g)
 
@@ -64,10 +63,10 @@ class StructTest2(StructTestFunction):
     """
 
     def f(self, x):
-        return (x - 30) * numpy.sin(x)
+        return (x - 30) * np.sin(x)
 
     def g(x):
-        return 58 - numpy.sum(x, axis=0)
+        return 58 - np.sum(x, axis=0)
 
     cons = wrap_constraints(g)
 
@@ -77,29 +76,29 @@ test2_1 = StructTest2(bounds=[(0, 60)],
                       expected_fun=-28.44677132,
                       # Important: test that funl return is in the correct
                       # order
-                      expected_xl=numpy.array([[1.53567906],
-                                               [55.01782167],
-                                               [7.80894889],
-                                               [48.74797493],
-                                               [14.07445705],
-                                               [42.4913859],
-                                               [20.31743841],
-                                               [36.28607535],
-                                               [26.43039605],
-                                               [30.76371366]]),
+                      expected_xl=np.array([[1.53567906],
+                                            [55.01782167],
+                                            [7.80894889],
+                                            [48.74797493],
+                                            [14.07445705],
+                                            [42.4913859],
+                                            [20.31743841],
+                                            [36.28607535],
+                                            [26.43039605],
+                                            [30.76371366]]),
 
-                      expected_funl=numpy.array([-28.44677132, -24.99785984,
-                                                 -22.16855376, -18.72136195,
-                                                 -15.89423937, -12.45154942,
-                                                 -9.63133158, -6.20801301,
-                                                 -3.43727232, -0.46353338])
+                      expected_funl=np.array([-28.44677132, -24.99785984,
+                                              -22.16855376, -18.72136195,
+                                              -15.89423937, -12.45154942,
+                                              -9.63133158, -6.20801301,
+                                              -3.43727232, -0.46353338])
                       )
 
 test2_2 = StructTest2(bounds=[(0, 4.5)],
                       expected_x=[1.53567906],
                       expected_fun=[-28.44677132],
-                      expected_xl=numpy.array([[1.53567906]]),
-                      expected_funl=numpy.array([-28.44677132])
+                      expected_xl=np.array([[1.53567906]]),
+                      expected_funl=np.array([-28.44677132])
                       )
 
 
@@ -189,10 +188,10 @@ test4_1 = StructTest4(bounds=[(-10, 10), ] * 7,
 
 class StructTest5(StructTestFunction):
     def f(self, x):
-        return (-(x[1] + 47.0)
-                * numpy.sin(numpy.sqrt(abs(x[0] / 2.0 + (x[1] + 47.0))))
-                - x[0] * numpy.sin(numpy.sqrt(abs(x[0] - (x[1] + 47.0))))
-                )
+        return (
+            -(x[1] + 47.0)*np.sin(np.sqrt(abs(x[0]/2.0 + (x[1] + 47.0))))
+            - x[0]*np.sin(np.sqrt(abs(x[0] - (x[1] + 47.0))))
+        )
 
     g = None
     cons = wrap_constraints(g)
@@ -259,7 +258,7 @@ class StructTestS(StructTestFunction):
 
 test_s = StructTestS(bounds=[(0, 2.0), ] * 4,
                      expected_fun=0.0,
-                     expected_x=numpy.ones(4) - 0.5
+                     expected_x=np.ones(4) - 0.5
                      )
 
 
@@ -321,25 +320,25 @@ def run_test(test, args=(), test_atol=1e-5, n=100, iters=None,
     print(f'res = {res}')
     logging.info(f'res = {res}')
     if test.expected_x is not None:
-        numpy.testing.assert_allclose(res.x, test.expected_x,
-                                      rtol=test_atol,
-                                      atol=test_atol)
+        np.testing.assert_allclose(res.x, test.expected_x,
+                                   rtol=test_atol,
+                                   atol=test_atol)
 
     # (Optional tests)
     if test.expected_fun is not None:
-        numpy.testing.assert_allclose(res.fun,
-                                      test.expected_fun,
-                                      atol=test_atol)
+        np.testing.assert_allclose(res.fun,
+                                   test.expected_fun,
+                                   atol=test_atol)
 
     if test.expected_xl is not None:
-        numpy.testing.assert_allclose(res.xl,
-                                      test.expected_xl,
-                                      atol=test_atol)
+        np.testing.assert_allclose(res.xl,
+                                   test.expected_xl,
+                                   atol=test_atol)
 
     if test.expected_funl is not None:
-        numpy.testing.assert_allclose(res.funl,
-                                      test.expected_funl,
-                                      atol=test_atol)
+        np.testing.assert_allclose(res.funl,
+                                   test.expected_funl,
+                                   atol=test_atol)
     return
 
 
@@ -471,8 +470,9 @@ class TestShgoSimplicialTestFunctions:
                  options=options, iters=1,
                  sampling_method='simplicial')
 
+    @pytest.mark.fail_slow(10)
     def test_f5_3_cons_symmetry(self):
-        """Assymmetrically constrained test function"""
+        """Asymmetrically constrained test function"""
         options = {'symmetry': [0, 0, 0, 3],
                    'disp': True}
 
@@ -486,10 +486,10 @@ class TestShgoSimplicialTestFunctions:
         """Return a minimum on a perfectly symmetric problem, based on
             gh10429"""
         avg = 0.5  # Given average value of x
-        cons = {'type': 'eq', 'fun': lambda x: numpy.mean(x) - avg}
+        cons = {'type': 'eq', 'fun': lambda x: np.mean(x) - avg}
 
         # Minimize the variance of x under the given constraint
-        res = shgo(numpy.var, bounds=6 * [(0, 1)], constraints=cons)
+        res = shgo(np.var, bounds=6 * [(0, 1)], constraints=cons)
         assert res.success
         assert_allclose(res.fun, 0, atol=1e-15)
         assert_allclose(res.x, 0.5)
@@ -530,9 +530,8 @@ class TestShgoArguments:
         res = shgo(test2_1.f, test2_1.bounds, constraints=test2_1.cons,
                    n=None, iters=1, sampling_method='sobol')
 
-        numpy.testing.assert_allclose(res.x, test2_1.expected_x, rtol=1e-5,
-                                      atol=1e-5)
-        numpy.testing.assert_allclose(res.fun, test2_1.expected_fun, atol=1e-5)
+        np.testing.assert_allclose(res.x, test2_1.expected_x, rtol=1e-5, atol=1e-5)
+        np.testing.assert_allclose(res.fun, test2_1.expected_fun, atol=1e-5)
 
     def test_3_1_disp_simplicial(self):
         """Iterative sampling on TestFunction 1 and 2  (multi and univariate)
@@ -583,7 +582,7 @@ class TestShgoArguments:
 
     @pytest.mark.slow
     def test_4_2_known_f_min(self):
-        """Test Global mode limiting local evalutions"""
+        """Test Global mode limiting local evaluations"""
         options = {  # Specify known function value
             'f_min': test4_1.expected_fun,
             'f_tol': 1e-6,
@@ -607,44 +606,39 @@ class TestShgoArguments:
         res = shgo(test2_1.f, test2_1.bounds, constraints=test2_1.cons,
                    n=None, iters=None, options=options,
                    sampling_method='sobol')
-        numpy.testing.assert_allclose(res.x, test2_1.expected_x, rtol=1e-5,
-                                      atol=1e-5)
+        np.testing.assert_allclose(res.x, test2_1.expected_x, rtol=1e-5, atol=1e-5)
 
     def test_5_1_simplicial_argless(self):
         """Test Default simplicial sampling settings on TestFunction 1"""
         res = shgo(test1_1.f, test1_1.bounds, constraints=test1_1.cons)
-        numpy.testing.assert_allclose(res.x, test1_1.expected_x, rtol=1e-5,
-                                      atol=1e-5)
+        np.testing.assert_allclose(res.x, test1_1.expected_x, rtol=1e-5, atol=1e-5)
 
     def test_5_2_sobol_argless(self):
         """Test Default sobol sampling settings on TestFunction 1"""
         res = shgo(test1_1.f, test1_1.bounds, constraints=test1_1.cons,
                    sampling_method='sobol')
-        numpy.testing.assert_allclose(res.x, test1_1.expected_x, rtol=1e-5,
-                                      atol=1e-5)
+        np.testing.assert_allclose(res.x, test1_1.expected_x, rtol=1e-5, atol=1e-5)
 
     def test_6_1_simplicial_max_iter(self):
         """Test that maximum iteration option works on TestFunction 3"""
         options = {'max_iter': 2}
         res = shgo(test3_1.f, test3_1.bounds, constraints=test3_1.cons,
                    options=options, sampling_method='simplicial')
-        numpy.testing.assert_allclose(res.x, test3_1.expected_x, rtol=1e-5,
-                                      atol=1e-5)
-        numpy.testing.assert_allclose(res.fun, test3_1.expected_fun, atol=1e-5)
+        np.testing.assert_allclose(res.x, test3_1.expected_x, rtol=1e-5, atol=1e-5)
+        np.testing.assert_allclose(res.fun, test3_1.expected_fun, atol=1e-5)
 
     def test_6_2_simplicial_min_iter(self):
         """Test that maximum iteration option works on TestFunction 3"""
         options = {'min_iter': 2}
         res = shgo(test3_1.f, test3_1.bounds, constraints=test3_1.cons,
                    options=options, sampling_method='simplicial')
-        numpy.testing.assert_allclose(res.x, test3_1.expected_x, rtol=1e-5,
-                                      atol=1e-5)
-        numpy.testing.assert_allclose(res.fun, test3_1.expected_fun, atol=1e-5)
+        np.testing.assert_allclose(res.x, test3_1.expected_x, rtol=1e-5, atol=1e-5)
+        np.testing.assert_allclose(res.fun, test3_1.expected_fun, atol=1e-5)
 
     def test_7_1_minkwargs(self):
         """Test the minimizer_kwargs arguments for solvers with constraints"""
         # Test solvers
-        for solver in ['COBYLA', 'SLSQP']:
+        for solver in ['COBYLA', 'COBYQA', 'SLSQP']:
             # Note that passing global constraints to SLSQP is tested in other
             # unittests which run test4_1 normally
             minimizer_kwargs = {'method': solver,
@@ -666,10 +660,10 @@ class TestShgoArguments:
                        'L-BFGS-B', 'TNC', 'dogleg', 'trust-ncg', 'trust-exact',
                        'trust-krylov']:
             def jac(x):
-                return numpy.array([2 * x[0], 2 * x[1]]).T
+                return np.array([2 * x[0], 2 * x[1]]).T
 
             def hess(x):
-                return numpy.array([[2, 0], [0, 2]])
+                return np.array([[2, 0], [0, 2]])
 
             minimizer_kwargs = {'method': solver,
                                 'jac': jac,
@@ -711,8 +705,8 @@ class TestShgoArguments:
                    'disp': True}
         res = shgo(test1_2.f, test1_2.bounds, n=10, iters=None,
                    options=options, sampling_method='sobol')
-        numpy.testing.assert_equal(0, res.x[0])
-        numpy.testing.assert_equal(0, res.x[1])
+        np.testing.assert_equal(0, res.x[0])
+        np.testing.assert_equal(0, res.x[1])
 
     # @nottest
     @pytest.mark.skip(reason="no way of currently testing this")
@@ -725,7 +719,7 @@ class TestShgoArguments:
                    'f_min': 0.0}
         res = shgo(test1_2.f, test1_2.bounds, n=1, iters=None,
                    options=options, sampling_method='sobol')
-        numpy.testing.assert_equal(0.0, res.fun)
+        np.testing.assert_equal(0.0, res.fun)
 
     def test_13_high_sobol(self):
         """Test init of high-dimensional sobol sequences"""
@@ -749,7 +743,7 @@ class TestShgoArguments:
         run_test(test1_1, n=1, iters=7, options=options,
                  sampling_method='sobol')
 
-    def test_16_disp_bounds_minimizer(self):
+    def test_16_disp_bounds_minimizer(self, capsys):
         """Test disp=True with minimizers that do not support bounds """
         options = {'disp': True}
         minimizer_kwargs = {'method': 'nelder-mead'}
@@ -760,14 +754,14 @@ class TestShgoArguments:
         """Test the functionality to add custom sampling methods to shgo"""
 
         def sample(n, d):
-            return numpy.random.uniform(size=(n, d))
+            return np.random.uniform(size=(n, d))
 
         run_test(test1_1, n=30, sampling_method=sample)
 
     def test_18_bounds_class(self):
         # test that new and old bounds yield same result
         def f(x):
-            return numpy.square(x).sum()
+            return np.square(x).sum()
 
         lb = [-6., 1., -5.]
         ub = [-1., 3., 5.]
@@ -780,11 +774,11 @@ class TestShgoArguments:
         assert res_new_bounds.nfev == res_old_bounds.nfev
         assert res_new_bounds.message == res_old_bounds.message
         assert res_new_bounds.success == res_old_bounds.success
-        x_opt = numpy.array([-1., 1., 0.])
-        numpy.testing.assert_allclose(res_new_bounds.x, x_opt)
-        numpy.testing.assert_allclose(res_new_bounds.x,
-                                      res_old_bounds.x)
+        x_opt = np.array([-1., 1., 0.])
+        np.testing.assert_allclose(res_new_bounds.x, x_opt)
+        np.testing.assert_allclose(res_new_bounds.x, res_old_bounds.x)
 
+    @pytest.mark.fail_slow(10)
     def test_19_parallelization(self):
         """Test the functionality to add custom sampling methods to shgo"""
 
@@ -799,10 +793,10 @@ class TestShgoArguments:
         """Test that constraints can be passed to arguments"""
 
         def eggholder(x):
-            return (-(x[1] + 47.0)
-                    * numpy.sin(numpy.sqrt(abs(x[0] / 2.0 + (x[1] + 47.0))))
-                    - x[0] * numpy.sin(numpy.sqrt(abs(x[0] - (x[1] + 47.0))))
-                    )
+            return (
+                -(x[1] + 47.0)*np.sin(np.sqrt(abs(x[0] / 2.0 + (x[1] + 47.0))))
+                - x[0]*np.sin(np.sqrt(abs(x[0] - (x[1] + 47.0))))
+            )
 
         def f(x):  # (cattle-feed)
             return 24.55 * x[0] + 26.75 * x[1] + 39 * x[2] + 40.50 * x[3]
@@ -814,10 +808,12 @@ class TestShgoArguments:
                 3] - 5  # >=0
 
         def g2(x):
-            return (12 * x[0] + 11.9 * x[1] + 41.8 * x[2] + 52.1 * x[3] - 21
-                    - 1.645 * numpy.sqrt(0.28 * x[0] ** 2 + 0.19 * x[1] ** 2
-                                         + 20.5 * x[2] ** 2 + 0.62 * x[3] ** 2)
-                    )  # >=0
+            return (
+                12*x[0] + 11.9*x[1] + 41.8*x[2] + 52.1*x[3] - 21
+                - 1.645*np.sqrt(
+                    0.28*x[0]**2 + 0.19*x[1]**2 + 20.5*x[2]**2 + 0.62*x[3]**2
+                )
+            )  # >=0
 
         def h1(x):
             return x[0] + x[1] + x[2] + x[3] - 1  # == 0
@@ -836,7 +832,7 @@ class TestShgoArguments:
         gradient alongside the objective value. Fixes gh-13547"""
         # previous
         def func(x):
-            return numpy.sum(numpy.power(x, 2)), 2 * x
+            return np.sum(np.power(x, 2)), 2 * x
 
         shgo(
             func,
@@ -848,7 +844,7 @@ class TestShgoArguments:
 
         # new
         def func(x):
-            return numpy.sum(x ** 2), 2 * x
+            return np.sum(x ** 2), 2 * x
 
         bounds = [[-1, 1], [1, 2], [-1, 1], [1, 2], [0, 3]]
 
@@ -889,8 +885,8 @@ class TestShgoArguments:
                        **options)
 
         assert res.success
-        numpy.testing.assert_allclose(res.fun, ref.fun)
-        numpy.testing.assert_allclose(res.x, ref.x)
+        np.testing.assert_allclose(res.fun, ref.fun)
+        np.testing.assert_allclose(res.x, ref.x)
 
     def test_21_3_hess_options_rosen(self):
         """Ensure the Hessian gets passed correctly to the local minimizer
@@ -901,7 +897,7 @@ class TestShgoArguments:
         minimizer_kwargs = {'method': 'Newton-CG'}
         res = shgo(rosen, bounds, minimizer_kwargs=minimizer_kwargs,
                    options=options)
-        ref = minimize(rosen, numpy.zeros(5), method='Newton-CG',
+        ref = minimize(rosen, np.zeros(5), method='Newton-CG',
                        **options)
         assert res.success
         assert_allclose(res.fun, ref.fun)
@@ -919,7 +915,7 @@ class TestShgoArguments:
         bounds = [(0, 10)]
         res = shgo(fun, bounds, args=(1,), constraints=constraints,
                    sampling_method='sobol')
-        ref = minimize(fun, numpy.zeros(1), bounds=bounds, args=(1,),
+        ref = minimize(fun, np.zeros(1), bounds=bounds, args=(1,),
                        constraints=constraints)
         assert res.success
         assert_allclose(res.fun, ref.fun)
@@ -934,9 +930,9 @@ class TestShgoFailures:
         res = shgo(test4_1.f, test4_1.bounds, n=2, iters=None,
                    options=options, sampling_method='sobol')
 
-        numpy.testing.assert_equal(False, res.success)
-        # numpy.testing.assert_equal(4, res.nfev)
-        numpy.testing.assert_equal(4, res.tnev)
+        np.testing.assert_equal(False, res.success)
+        # np.testing.assert_equal(4, res.nfev)
+        np.testing.assert_equal(4, res.tnev)
 
     def test_2_sampling(self):
         """Rejection of unknown sampling method"""
@@ -951,9 +947,9 @@ class TestShgoFailures:
                    'disp': True}
         res = shgo(test_table.f, test_table.bounds, n=3, options=options,
                    sampling_method='sobol')
-        numpy.testing.assert_equal(False, res.success)
-        # numpy.testing.assert_equal(9, res.nfev)
-        numpy.testing.assert_equal(12, res.nfev)
+        np.testing.assert_equal(False, res.success)
+        # np.testing.assert_equal(9, res.nfev)
+        np.testing.assert_equal(12, res.nfev)
 
     def test_3_2_no_min_pool_simplicial(self):
         """Check that the routine stops when no minimiser is found
@@ -962,7 +958,7 @@ class TestShgoFailures:
                    'disp': True}
         res = shgo(test_table.f, test_table.bounds, n=3, options=options,
                    sampling_method='simplicial')
-        numpy.testing.assert_equal(False, res.success)
+        np.testing.assert_equal(False, res.success)
 
     def test_4_1_bound_err(self):
         """Specified bounds ub > lb"""
@@ -984,7 +980,7 @@ class TestShgoFailures:
                    constraints=test_infeasible.cons, n=100, options=options,
                    sampling_method='sobol')
 
-        numpy.testing.assert_equal(False, res.success)
+        np.testing.assert_equal(False, res.success)
 
     def test_5_1_2_infeasible_sobol(self):
         """Ensures the algorithm terminates on infeasible problems
@@ -997,7 +993,7 @@ class TestShgoFailures:
                    constraints=test_infeasible.cons, n=100, options=options,
                    sampling_method='sobol')
 
-        numpy.testing.assert_equal(False, res.success)
+        np.testing.assert_equal(False, res.success)
 
     def test_5_2_infeasible_simplicial(self):
         """Ensures the algorithm terminates on infeasible problems
@@ -1009,8 +1005,9 @@ class TestShgoFailures:
                    constraints=test_infeasible.cons, n=100, options=options,
                    sampling_method='simplicial')
 
-        numpy.testing.assert_equal(False, res.success)
+        np.testing.assert_equal(False, res.success)
 
+    @pytest.mark.thread_unsafe
     def test_6_1_lower_known_f_min(self):
         """Test Global mode limiting local evaluations with f* too high"""
         options = {  # Specify known function value
@@ -1055,7 +1052,7 @@ class TestShgoReturns:
         fun.nfev = 0
 
         result = shgo(fun, bounds)
-        numpy.testing.assert_equal(fun.nfev, result.nfev)
+        np.testing.assert_equal(fun.nfev, result.nfev)
 
     def test_1_nfev_sobol(self):
         bounds = [(0, 2), (0, 2), (0, 2), (0, 2), (0, 2)]
@@ -1067,7 +1064,7 @@ class TestShgoReturns:
         fun.nfev = 0
 
         result = shgo(fun, bounds, sampling_method='sobol')
-        numpy.testing.assert_equal(fun.nfev, result.nfev)
+        np.testing.assert_equal(fun.nfev, result.nfev)
 
 
 def test_vector_constraint():
