@@ -4,6 +4,7 @@ import numpy as np
 from numpy.linalg import norm
 from numpy.testing import (assert_, assert_allclose,
                            assert_equal, suppress_warnings)
+import pytest
 from pytest import raises as assert_raises
 from scipy.sparse import issparse, lil_matrix
 from scipy.sparse.linalg import aslinearoperator
@@ -76,7 +77,7 @@ def fun_bvp(x):
 
 class BroydenTridiagonal:
     def __init__(self, n=100, mode='sparse'):
-        np.random.seed(0)
+        rng = np.random.RandomState(0)
 
         self.n = n
 
@@ -84,10 +85,10 @@ class BroydenTridiagonal:
         self.lb = np.linspace(-2, -1.5, n)
         self.ub = np.linspace(-0.8, 0.0, n)
 
-        self.lb += 0.1 * np.random.randn(n)
-        self.ub += 0.1 * np.random.randn(n)
+        self.lb += 0.1 * rng.randn(n)
+        self.ub += 0.1 * rng.randn(n)
 
-        self.x0 += 0.1 * np.random.randn(n)
+        self.x0 += 0.1 * rng.randn(n)
         self.x0 = make_strictly_feasible(self.x0, self.lb, self.ub)
 
         if mode == 'sparse':
@@ -131,7 +132,7 @@ class ExponentialFittingProblem:
 
     def __init__(self, a, b, noise, n_outliers=1, x_range=(-1, 1),
                  n_points=11, random_seed=None):
-        np.random.seed(random_seed)
+        rng = np.random.RandomState(random_seed)
         self.m = n_points
         self.n = 2
 
@@ -139,10 +140,10 @@ class ExponentialFittingProblem:
         self.x = np.linspace(x_range[0], x_range[1], n_points)
 
         self.y = a + np.exp(b * self.x)
-        self.y += noise * np.random.randn(self.m)
+        self.y += noise * rng.randn(self.m)
 
-        outliers = np.random.randint(0, self.m, n_outliers)
-        self.y[outliers] += 50 * noise * np.random.rand(n_outliers)
+        outliers = rng.randint(0, self.m, n_outliers)
+        self.y[outliers] += 50 * noise * rng.rand(n_outliers)
 
         self.p_opt = np.array([a, b])
 
@@ -182,8 +183,10 @@ class BaseMixin:
         a = 3.0
         for jac in ['2-point', '3-point', 'cs', jac_trivial]:
             with suppress_warnings() as sup:
-                sup.filter(UserWarning,
-                           "jac='(3-point|cs)' works equivalently to '2-point' for method='lm'")
+                sup.filter(
+                    UserWarning,
+                    "jac='(3-point|cs)' works equivalently to '2-point' for method='lm'"
+                )
                 res = least_squares(fun_trivial, 2.0, jac, args=(a,),
                                     method=self.method)
                 res1 = least_squares(fun_trivial, 2.0, jac, kwargs={'a': a},
@@ -200,8 +203,10 @@ class BaseMixin:
     def test_jac_options(self):
         for jac in ['2-point', '3-point', 'cs', jac_trivial]:
             with suppress_warnings() as sup:
-                sup.filter(UserWarning,
-                           "jac='(3-point|cs)' works equivalently to '2-point' for method='lm'")
+                sup.filter(
+                    UserWarning,
+                    "jac='(3-point|cs)' works equivalently to '2-point' for method='lm'"
+                )
                 res = least_squares(fun_trivial, 2.0, jac, method=self.method)
             assert_allclose(res.x, 0, atol=1e-4)
 
@@ -296,8 +301,10 @@ class BaseMixin:
                 [1.0, np.array([1.0, 0.2]), 'jac'],
                 ['exact', 'lsmr']):
             with suppress_warnings() as sup:
-                sup.filter(UserWarning,
-                           "jac='(3-point|cs)' works equivalently to '2-point' for method='lm'")
+                sup.filter(
+                    UserWarning,
+                    "jac='(3-point|cs)' works equivalently to '2-point' for method='lm'"
+                )
                 res = least_squares(fun_rosenbrock, x0, jac, x_scale=x_scale,
                                     tr_solver=tr_solver, method=self.method)
             assert_allclose(res.x, x_opt)
@@ -397,7 +404,7 @@ class BoundsMixin:
     def test_inconsistent_shape(self):
         assert_raises(ValueError, least_squares, fun_trivial, 2.0,
                       bounds=(1.0, [2.0, 3.0]), method=self.method)
-        # 1-D array wont't be broadcasted
+        # 1-D array won't be broadcast
         assert_raises(ValueError, least_squares, fun_rosenbrock, [1.0, 2.0],
                       bounds=([0.0], [3.0, 4.0]), method=self.method)
 
@@ -461,6 +468,7 @@ class BoundsMixin:
                             bounds=Bounds(lb=[0.1, 0.1]))
         assert_allclose(res.x, [0.1, 0.1], atol=1e-5)
 
+    @pytest.mark.fail_slow(10)
     def test_rosenbrock_bounds(self):
         x0_1 = np.array([-2.0, 1.0])
         x0_2 = np.array([2.0, 2.0])
@@ -546,6 +554,7 @@ class SparseMixin:
             assert_allclose(res_dense.cost, 0, atol=1e-20)
             assert_allclose(res_sparse.cost, 0, atol=1e-20)
 
+    @pytest.mark.fail_slow(10)
     def test_with_bounds(self):
         p = BroydenTridiagonal()
         for jac, jac_sparsity in product(
@@ -789,10 +798,10 @@ def test_small_tolerances_for_lm():
 def test_fp32_gh12991():
     # checks that smaller FP sizes can be used in least_squares
     # this is the minimum working example reported for gh12991
-    np.random.seed(1)
+    rng = np.random.RandomState(1)
 
     x = np.linspace(0, 1, 100).astype("float32")
-    y = np.random.random(100).astype("float32")
+    y = rng.random(100).astype("float32")
 
     def func(p, x):
         return p[0] + p[1] * x
