@@ -40,11 +40,12 @@ import warnings
 from scipy.sparse.linalg._interface import aslinearoperator, LinearOperator
 from scipy.sparse import eye, issparse
 from scipy.linalg import eig, eigh, lu_factor, lu_solve
-from scipy.sparse._sputils import isdense, is_pydata_spmatrix
+from scipy.sparse._sputils import (
+    convert_pydata_sparse_to_scipy, isdense, is_pydata_spmatrix,
+)
 from scipy.sparse.linalg import gmres, splu
 from scipy._lib._util import _aligned_zeros
 from scipy._lib._threadsafety import ReentrancyLock
-
 from . import _arpack
 arpack_int = _arpack.timing.nbx.dtype
 
@@ -275,9 +276,12 @@ class ArpackError(RuntimeError):
     ARPACK error
     """
 
-    def __init__(self, info, infodict=_NAUPD_ERRORS):
+    def __init__(self, info, infodict=None):
+        if infodict is None:
+            infodict = _NAUPD_ERRORS
+
         msg = infodict.get(info, "Unknown error")
-        RuntimeError.__init__(self, "ARPACK error %d: %s" % (info, msg))
+        super().__init__(f"ARPACK error {info}: {msg}")
 
 
 class ArpackNoConvergence(ArpackError):
@@ -319,7 +323,11 @@ class _ArpackParams:
             raise ValueError("maxiter must be positive, maxiter=%d" % maxiter)
 
         if tp not in 'fdFD':
-            raise ValueError("matrix type must be 'f', 'd', 'F', or 'D'")
+            # Use `float64` libraries from integer dtypes.
+            if np.can_cast(tp, 'd'):
+                tp = 'd'
+            else:
+                raise ValueError("matrix type must be 'f', 'd', 'F', or 'D'")
 
         if v0 is not None:
             # ARPACK overwrites its initial resid,  make a copy
@@ -505,8 +513,7 @@ class _SymmetricArpackParams(_ArpackParams):
             raise ValueError("mode=%i not implemented" % mode)
 
         if which not in _SEUPD_WHICH:
-            raise ValueError("which must be one of %s"
-                             % ' '.join(_SEUPD_WHICH))
+            raise ValueError(f"which must be one of {' '.join(_SEUPD_WHICH)}")
         if k >= n:
             raise ValueError("k must be less than ndim(A), k=%d" % k)
 
@@ -514,7 +521,7 @@ class _SymmetricArpackParams(_ArpackParams):
                                ncv, v0, maxiter, which, tol)
 
         if self.ncv > n or self.ncv <= k:
-            raise ValueError("ncv must be k<ncv<=n, ncv=%s" % self.ncv)
+            raise ValueError(f"ncv must be k<ncv<=n, ncv={self.ncv}")
 
         # Use _aligned_zeros to work around a f2py bug in Numpy 1.9.1
         self.workd = _aligned_zeros(3 * n, self.tp)
@@ -688,8 +695,7 @@ class _UnsymmetricArpackParams(_ArpackParams):
             raise ValueError("mode=%i not implemented" % mode)
 
         if which not in _NEUPD_WHICH:
-            raise ValueError("Parameter which must be one of %s"
-                             % ' '.join(_NEUPD_WHICH))
+            raise ValueError(f"Parameter which must be one of {' '.join(_NEUPD_WHICH)}")
         if k >= n - 1:
             raise ValueError("k must be less than ndim(A)-1, k=%d" % k)
 
@@ -697,7 +703,7 @@ class _UnsymmetricArpackParams(_ArpackParams):
                                ncv, v0, maxiter, which, tol)
 
         if self.ncv > n or self.ncv <= k + 1:
-            raise ValueError("ncv must be k+1<ncv<=n, ncv=%s" % self.ncv)
+            raise ValueError(f"ncv must be k+1<ncv<=n, ncv={self.ncv}")
 
         # Use _aligned_zeros to work around a f2py bug in Numpy 1.9.1
         self.workd = _aligned_zeros(3 * n, self.tp)
@@ -720,17 +726,20 @@ class _UnsymmetricArpackParams(_ArpackParams):
 
     def iterate(self):
         if self.tp in 'fd':
-            self.ido, self.tol, self.resid, self.v, self.iparam, self.ipntr, self.info =\
-                self._arpack_solver(self.ido, self.bmat, self.which, self.k,
-                                    self.tol, self.resid, self.v, self.iparam,
-                                    self.ipntr, self.workd, self.workl,
-                                    self.info)
+            results = self._arpack_solver(self.ido, self.bmat, self.which, self.k,
+                                          self.tol, self.resid, self.v, self.iparam,
+                                          self.ipntr, self.workd, self.workl, self.info)
+            self.ido, self.tol, self.resid, self.v, \
+                self.iparam, self.ipntr, self.info = results
+
         else:
-            self.ido, self.tol, self.resid, self.v, self.iparam, self.ipntr, self.info =\
-                self._arpack_solver(self.ido, self.bmat, self.which, self.k,
-                                    self.tol, self.resid, self.v, self.iparam,
-                                    self.ipntr, self.workd, self.workl,
-                                    self.rwork, self.info)
+            results = self._arpack_solver(self.ido, self.bmat, self.which, self.k,
+                                          self.tol, self.resid, self.v, self.iparam,
+                                          self.ipntr, self.workd, self.workl,
+                                          self.rwork, self.info)
+            self.ido, self.tol, self.resid, self.v, \
+                self.iparam, self.ipntr, self.info = results
+
 
         xslice = slice(self.ipntr[0] - 1, self.ipntr[0] - 1 + self.n)
         yslice = slice(self.ipntr[1] - 1, self.ipntr[1] - 1 + self.n)
@@ -895,15 +904,6 @@ class _UnsymmetricArpackParams(_ArpackParams):
         else:
             return d
 
-
-def _aslinearoperator_with_dtype(m):
-    m = aslinearoperator(m)
-    if not hasattr(m, 'dtype'):
-        x = np.zeros(m.shape[1])
-        m.dtype = (m * x).dtype
-    return m
-
-
 class SpLuInv(LinearOperator):
     """
     SpLuInv:
@@ -950,7 +950,7 @@ def gmres_loose(A, b, tol):
     """
     b = np.asarray(b)
     min_tol = 1000 * np.sqrt(b.size) * np.finfo(b.dtype).eps
-    return gmres(A, b, tol=max(tol, min_tol), atol=0)
+    return gmres(A, b, rtol=max(tol, min_tol), atol=0)
 
 
 class IterInv(LinearOperator):
@@ -1077,13 +1077,13 @@ def get_OPinv_matvec(A, M, sigma, hermitian=False, tol=0):
             A = _fast_spmatrix_to_csc(A, hermitian=hermitian)
             return SpLuInv(A).matvec
         else:
-            return IterOpInv(_aslinearoperator_with_dtype(A),
+            return IterOpInv(aslinearoperator(A),
                              M, sigma, tol=tol).matvec
     else:
         if ((not isdense(A) and not issparse(A) and not is_pydata_spmatrix(A)) or
                 (not isdense(M) and not issparse(M) and not is_pydata_spmatrix(A))):
-            return IterOpInv(_aslinearoperator_with_dtype(A),
-                             _aslinearoperator_with_dtype(M),
+            return IterOpInv(aslinearoperator(A),
+                             aslinearoperator(M),
                              sigma, tol=tol).matvec
         elif isdense(A) or isdense(M):
             return LuInv(A - sigma * M).matvec
@@ -1253,15 +1253,17 @@ def eigs(A, k=6, M=None, sigma=None, which='LM', v0=None,
     (13, 6)
 
     """
+    A = convert_pydata_sparse_to_scipy(A)
+    M = convert_pydata_sparse_to_scipy(M)
     if A.shape[0] != A.shape[1]:
         raise ValueError(f'expected square matrix (shape={A.shape})')
     if M is not None:
         if M.shape != A.shape:
-            raise ValueError('wrong M dimensions %s, should be %s'
-                             % (M.shape, A.shape))
+            raise ValueError(f'wrong M dimensions {M.shape}, should be {A.shape}')
         if np.dtype(M.dtype).char.lower() != np.dtype(A.dtype).char.lower():
             warnings.warn('M does not have the same type precision as A. '
-                          'This may adversely affect ARPACK convergence')
+                          'This may adversely affect ARPACK convergence',
+                          stacklevel=2)
 
     n = A.shape[0]
 
@@ -1271,7 +1273,7 @@ def eigs(A, k=6, M=None, sigma=None, which='LM', v0=None,
     if k >= n - 1:
         warnings.warn("k >= N - 1 for N * N square matrix. "
                       "Attempting to use scipy.linalg.eig instead.",
-                      RuntimeWarning)
+                      RuntimeWarning, stacklevel=2)
 
         if issparse(A):
             raise TypeError("Cannot use scipy.linalg.eig for sparse A with "
@@ -1287,7 +1289,7 @@ def eigs(A, k=6, M=None, sigma=None, which='LM', v0=None,
         return eig(A, b=M, right=return_eigenvectors)
 
     if sigma is None:
-        matvec = _aslinearoperator_with_dtype(A).matvec
+        matvec = aslinearoperator(A).matvec
 
         if OPinv is not None:
             raise ValueError("OPinv should not be specified "
@@ -1310,9 +1312,9 @@ def eigs(A, k=6, M=None, sigma=None, which='LM', v0=None,
             if Minv is None:
                 Minv_matvec = get_inv_matvec(M, hermitian=True, tol=tol)
             else:
-                Minv = _aslinearoperator_with_dtype(Minv)
+                Minv = aslinearoperator(Minv)
                 Minv_matvec = Minv.matvec
-            M_matvec = _aslinearoperator_with_dtype(M).matvec
+            M_matvec = aslinearoperator(M).matvec
     else:
         #sigma is not None: shift-invert mode
         if np.issubdtype(A.dtype, np.complexfloating):
@@ -1329,19 +1331,19 @@ def eigs(A, k=6, M=None, sigma=None, which='LM', v0=None,
         else:
             raise ValueError("OPpart must be one of ('r','i')")
 
-        matvec = _aslinearoperator_with_dtype(A).matvec
+        matvec = aslinearoperator(A).matvec
         if Minv is not None:
             raise ValueError("Minv should not be specified when sigma is")
         if OPinv is None:
             Minv_matvec = get_OPinv_matvec(A, M, sigma,
                                            hermitian=False, tol=tol)
         else:
-            OPinv = _aslinearoperator_with_dtype(OPinv)
+            OPinv = aslinearoperator(OPinv)
             Minv_matvec = OPinv.matvec
         if M is None:
             M_matvec = None
         else:
-            M_matvec = _aslinearoperator_with_dtype(M).matvec
+            M_matvec = aslinearoperator(M).matvec
 
     params = _UnsymmetricArpackParams(n, k, A.dtype.char, matvec, mode,
                                       M_matvec, Minv_matvec, sigma,
@@ -1563,8 +1565,7 @@ def eigsh(A, k=6, M=None, sigma=None, which='LM', v0=None,
     # complex Hermitian matrices should be solved with eigs
     if np.issubdtype(A.dtype, np.complexfloating):
         if mode != 'normal':
-            raise ValueError("mode=%s cannot be used with "
-                             "complex matrix A" % mode)
+            raise ValueError(f"mode={mode} cannot be used with complex matrix A")
         if which == 'BE':
             raise ValueError("which='BE' cannot be used with complex matrix A")
         elif which == 'LA':
@@ -1585,11 +1586,11 @@ def eigsh(A, k=6, M=None, sigma=None, which='LM', v0=None,
         raise ValueError(f'expected square matrix (shape={A.shape})')
     if M is not None:
         if M.shape != A.shape:
-            raise ValueError('wrong M dimensions %s, should be %s'
-                             % (M.shape, A.shape))
+            raise ValueError(f'wrong M dimensions {M.shape}, should be {A.shape}')
         if np.dtype(M.dtype).char.lower() != np.dtype(A.dtype).char.lower():
             warnings.warn('M does not have the same type precision as A. '
-                          'This may adversely affect ARPACK convergence')
+                          'This may adversely affect ARPACK convergence',
+                          stacklevel=2)
 
     n = A.shape[0]
 
@@ -1599,7 +1600,7 @@ def eigsh(A, k=6, M=None, sigma=None, which='LM', v0=None,
     if k >= n:
         warnings.warn("k >= N for N * N square matrix. "
                       "Attempting to use scipy.linalg.eigh instead.",
-                      RuntimeWarning)
+                      RuntimeWarning, stacklevel=2)
 
         if issparse(A):
             raise TypeError("Cannot use scipy.linalg.eigh for sparse A with "
@@ -1615,7 +1616,7 @@ def eigsh(A, k=6, M=None, sigma=None, which='LM', v0=None,
         return eigh(A, b=M, eigvals_only=not return_eigenvectors)
 
     if sigma is None:
-        A = _aslinearoperator_with_dtype(A)
+        A = aslinearoperator(A)
         matvec = A.matvec
 
         if OPinv is not None:
@@ -1635,9 +1636,9 @@ def eigsh(A, k=6, M=None, sigma=None, which='LM', v0=None,
             if Minv is None:
                 Minv_matvec = get_inv_matvec(M, hermitian=True, tol=tol)
             else:
-                Minv = _aslinearoperator_with_dtype(Minv)
+                Minv = aslinearoperator(Minv)
                 Minv_matvec = Minv.matvec
-            M_matvec = _aslinearoperator_with_dtype(M).matvec
+            M_matvec = aslinearoperator(M).matvec
     else:
         # sigma is not None: shift-invert mode
         if Minv is not None:
@@ -1651,12 +1652,12 @@ def eigsh(A, k=6, M=None, sigma=None, which='LM', v0=None,
                 Minv_matvec = get_OPinv_matvec(A, M, sigma,
                                                hermitian=True, tol=tol)
             else:
-                OPinv = _aslinearoperator_with_dtype(OPinv)
+                OPinv = aslinearoperator(OPinv)
                 Minv_matvec = OPinv.matvec
             if M is None:
                 M_matvec = None
             else:
-                M = _aslinearoperator_with_dtype(M)
+                M = aslinearoperator(M)
                 M_matvec = M.matvec
 
         # buckling mode
@@ -1666,27 +1667,27 @@ def eigsh(A, k=6, M=None, sigma=None, which='LM', v0=None,
                 Minv_matvec = get_OPinv_matvec(A, M, sigma,
                                                hermitian=True, tol=tol)
             else:
-                Minv_matvec = _aslinearoperator_with_dtype(OPinv).matvec
-            matvec = _aslinearoperator_with_dtype(A).matvec
+                Minv_matvec = aslinearoperator(OPinv).matvec
+            matvec = aslinearoperator(A).matvec
             M_matvec = None
 
         # cayley-transform mode
         elif mode == 'cayley':
             mode = 5
-            matvec = _aslinearoperator_with_dtype(A).matvec
+            matvec = aslinearoperator(A).matvec
             if OPinv is None:
                 Minv_matvec = get_OPinv_matvec(A, M, sigma,
                                                hermitian=True, tol=tol)
             else:
-                Minv_matvec = _aslinearoperator_with_dtype(OPinv).matvec
+                Minv_matvec = aslinearoperator(OPinv).matvec
             if M is None:
                 M_matvec = None
             else:
-                M_matvec = _aslinearoperator_with_dtype(M).matvec
+                M_matvec = aslinearoperator(M).matvec
 
         # unrecognized mode
         else:
-            raise ValueError("unrecognized mode '%s'" % mode)
+            raise ValueError(f"unrecognized mode '{mode}'")
 
     params = _SymmetricArpackParams(n, k, A.dtype.char, matvec, mode,
                                     M_matvec, Minv_matvec, sigma,
