@@ -13,9 +13,11 @@ from scipy.stats.sampling import (
     DiscreteGuideTable,
     NumericalInversePolynomial,
     NumericalInverseHermite,
+    RatioUniforms,
     SimpleRatioUniforms,
     UNURANError
 )
+from pytest import raises as assert_raises
 from scipy import stats
 from scipy import special
 from scipy.stats import chisquare, cramervonmises
@@ -63,7 +65,7 @@ bad_pdfs_common = [
     # Returning wrong type
     (lambda x: [], TypeError, floaterr),
     # Undefined name inside the function
-    (lambda x: foo, NameError, r"name 'foo' is not defined"),  # type: ignore[name-defined]  # noqa
+    (lambda x: foo, NameError, r"name 'foo' is not defined"),  # type: ignore[name-defined]  # noqa: F821, E501
     # Infinite value returned => Overflow error.
     (lambda x: np.inf, UNURANError, r"..."),
     # NaN value => internal error in UNU.RAN
@@ -82,7 +84,7 @@ bad_dpdf_common = [
     # Returning wrong type
     (lambda x: [], TypeError, floaterr),
     # Undefined name inside the function
-    (lambda x: foo, NameError, r"name 'foo' is not defined"),  # type: ignore[name-defined]  # noqa
+    (lambda x: foo, NameError, r"name 'foo' is not defined"),  # type: ignore[name-defined]  # noqa: F821, E501
     # signature of dPDF wrong
     (lambda: 1.0, TypeError, r"takes 0 positional arguments but 1 was given")
 ]
@@ -93,7 +95,7 @@ bad_logpdfs_common = [
     # Returning wrong type
     (lambda x: [], TypeError, floaterr),
     # Undefined name inside the function
-    (lambda x: foo, NameError, r"name 'foo' is not defined"),  # type: ignore[name-defined]  # noqa
+    (lambda x: foo, NameError, r"name 'foo' is not defined"),  # type: ignore[name-defined]  # noqa: F821, E501
     # Infinite value returned => Overflow error.
     (lambda x: np.inf, UNURANError, r"..."),
     # NaN value => internal error in UNU.RAN
@@ -632,8 +634,8 @@ class TestDiscreteAliasUrn:
     # DAU fails on these probably because of large domains and small
     # computation errors in PMF. Mean/SD match but chi-squared test fails.
     basic_fail_dists = {
-        'nchypergeom_fisher',  # numerical erros on tails
-        'nchypergeom_wallenius',  # numerical erros on tails
+        'nchypergeom_fisher',  # numerical errors on tails
+        'nchypergeom_wallenius',  # numerical errors on tails
         'randint'  # fails on 32-bit ubuntu
     }
 
@@ -672,7 +674,7 @@ class TestDiscreteAliasUrn:
         (lambda x: 0.0, ValueError,
          r"must contain at least one non-zero value"),
         # Undefined name inside the function
-        (lambda x: foo, NameError,  # type: ignore[name-defined]  # noqa
+        (lambda x: foo, NameError,  # type: ignore[name-defined]  # noqa: F821
          r"name 'foo' is not defined"),
         # Returning wrong type.
         (lambda x: [], ValueError,
@@ -925,6 +927,7 @@ class TestNumericalInversePolynomial:
         assert_allclose(res, expected, rtol=1e-11, atol=1e-11)
         assert res.shape == expected.shape
 
+    @pytest.mark.slow
     def test_u_error(self):
         dist = StandardNormal()
         rng = NumericalInversePolynomial(dist, u_resolution=1e-10)
@@ -988,7 +991,7 @@ class TestNumericalInversePolynomial:
         class MyDist:
             pass
 
-        # create genrator from dist with only pdf
+        # create generator from dist with only pdf
         dist_pdf = MyDist()
         dist_pdf.pdf = lambda x: math.exp(-x*x/2)
         rng1 = NumericalInversePolynomial(dist_pdf)
@@ -1106,6 +1109,7 @@ class TestNumericalInverseHermite:
         #     pytest.skip("Tested separately")
         self.basic_test_all_scipy_dists(distname, shapes)
 
+    @pytest.mark.fail_slow(5)
     @pytest.mark.filterwarnings('ignore::RuntimeWarning')
     def test_basic_truncnorm_gh17155(self):
         self.basic_test_all_scipy_dists("truncnorm", (0.1, 2))
@@ -1201,6 +1205,7 @@ class TestNumericalInverseHermite:
         assert_allclose(res, expected, rtol=1e-9, atol=3e-10)
         assert res.shape == expected.shape
 
+    @pytest.mark.slow
     def test_u_error(self):
         dist = StandardNormal()
         rng = NumericalInverseHermite(dist, u_resolution=1e-10)
@@ -1370,3 +1375,71 @@ class TestSimpleRatioUniforms:
         # pdf_area < 0
         with pytest.raises(ValueError, match=r"`pdf_area` must be > 0"):
             SimpleRatioUniforms(StandardNormal(), mode=0, pdf_area=-1)
+
+
+class TestRatioUniforms:
+    def test_rv_generation(self):
+        # use KS test to check distribution of rvs
+        # normal distribution
+        f = stats.norm.pdf
+        v = np.sqrt(f(np.sqrt(2))) * np.sqrt(2)
+        u = np.sqrt(f(0))
+        gen = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=12345)
+        assert_equal(stats.kstest(gen.rvs(2500), 'norm')[1] > 0.25, True)
+
+        # exponential distribution
+        gen = RatioUniforms(lambda x: np.exp(-x), umax=1,
+                            vmin=0, vmax=2*np.exp(-1), random_state=12345)
+        assert_equal(stats.kstest(gen.rvs(1000), 'expon')[1] > 0.25, True)
+
+    def test_shape(self):
+        # test shape of return value depending on size parameter
+        f = stats.norm.pdf
+        v = np.sqrt(f(np.sqrt(2))) * np.sqrt(2)
+        u = np.sqrt(f(0))
+
+        gen1 = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=1234)
+        gen2 = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=1234)
+        gen3 = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=1234)
+        r1, r2, r3 = gen1.rvs(3), gen2.rvs((3,)), gen3.rvs((3, 1))
+        assert_equal(r1, r2)
+        assert_equal(r2, r3.flatten())
+        assert_equal(r1.shape, (3,))
+        assert_equal(r3.shape, (3, 1))
+
+        gen4 = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=12)
+        gen5 = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=12)
+        r4, r5 = gen4.rvs(size=(3, 3, 3)), gen5.rvs(size=27)
+        assert_equal(r4.flatten(), r5)
+        assert_equal(r4.shape, (3, 3, 3))
+
+        gen6 = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=1234)
+        gen7 = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=1234)
+        gen8 = RatioUniforms(f, umax=u, vmin=-v, vmax=v, random_state=1234)
+        r6, r7, r8 = gen6.rvs(), gen7.rvs(1), gen8.rvs((1,))
+        assert_equal(r6, r7)
+        assert_equal(r7, r8)
+
+    def test_random_state(self):
+        f = stats.norm.pdf
+        v = np.sqrt(f(np.sqrt(2))) * np.sqrt(2)
+        umax = np.sqrt(f(0))
+        gen1 = RatioUniforms(f, umax=umax, vmin=-v, vmax=v, random_state=1234)
+        r1 = gen1.rvs(10)
+        np.random.seed(1234)
+        gen2 = RatioUniforms(f, umax=umax, vmin=-v, vmax=v)
+        r2 = gen2.rvs(10)
+        assert_equal(r1, r2)
+
+    def test_exceptions(self):
+        f = stats.norm.pdf
+        # need vmin < vmax
+        with assert_raises(ValueError, match="vmin must be smaller than vmax"):
+            RatioUniforms(pdf=f, umax=1, vmin=3, vmax=1)
+        with assert_raises(ValueError, match="vmin must be smaller than vmax"):
+            RatioUniforms(pdf=f, umax=1, vmin=1, vmax=1)
+        # need umax > 0
+        with assert_raises(ValueError, match="umax must be positive"):
+            RatioUniforms(pdf=f, umax=-1, vmin=1, vmax=3)
+        with assert_raises(ValueError, match="umax must be positive"):
+            RatioUniforms(pdf=f, umax=0, vmin=1, vmax=3)
