@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- encoding:utf-8 -*-
 """
 gh_lists.py MILESTONE
 
@@ -31,14 +30,14 @@ def main():
         milestones = get_milestones(getter, args.project)
         if args.milestone not in milestones:
             msg = "Milestone {0} not available. Available milestones: {1}"
-            msg = msg.format(args.milestone, u", ".join(sorted(milestones)))
+            msg = msg.format(args.milestone, ", ".join(sorted(milestones)))
             p.error(msg)
         issues = get_issues(getter, args.project, args.milestone)
         issues.sort()
     finally:
         getter.save()
 
-    prs = [x for x in issues if u'/pull/' in x.url]
+    prs = [x for x in issues if '/pull/' in x.url]
     issues = [x for x in issues if x not in prs]
 
     def print_list(title, items):
@@ -47,37 +46,66 @@ def main():
         print("-"*len(title))
         print()
 
+        def backtick_repl(matchobj):
+            """repl to add an escaped space following a code block if needed"""
+            if matchobj.group(2) != ' ':
+                post = r'\ ' + matchobj.group(2)
+            else:
+                post = matchobj.group(2)
+            return '``' + matchobj.group(1) + '``' + post
+
         for issue in items:
-            msg = u"* `#{0} <{1}>`__: {2}"
-            # sanitize whitespace, `, and *
-            title = re.sub(u"\\s+", u" ", issue.title.strip())
-            title = title.replace(u'`', u'\\`').replace(u'*', u'\\*')
+            msg = "* `#{0} <{1}>`__: {2}"
+            # sanitize whitespace
+            title = re.sub("\\s+", " ", issue.title.strip())
+
+            # substitute any single backtick not adjacent to a backtick
+            # for a double backtick
+            title = re.sub("(?P<pre>(?:^|(?<=[^`])))`(?P<post>(?=[^`]|$))",
+                           r"\g<pre>``\g<post>",
+                           title)
+            # add an escaped space if code block is not followed by a space
+            title = re.sub("``(.*?)``(.)", backtick_repl, title)
+
+            # sanitize asterisks
+            title = title.replace('*', '\\*')
+
             if len(title) > 60:
-                remainder = re.sub(u"\\s.*$", u"...", title[60:])
+                remainder = re.sub("\\s.*$", "...", title[60:])
                 if len(remainder) > 20:
-                    remainder = title[:80] + u"..."
+                    # just use the first 80 characters, with ellipses.
+                    # note: this was previously bugged,
+                    # assigning to `remainder` rather than `title`
+                    title = title[:80] + "..."
                 else:
+                    # use the first 60 characters and the next word
                     title = title[:60] + remainder
+
+                if title.count('`') % 4 != 0:
+                    # ellipses have cut in the middle of a code block,
+                    # so finish the code block before the ellipses
+                    title = title[:-3] + '``...'
+
             msg = msg.format(issue.id, issue.url, title)
             print(msg)
         print()
 
-    msg = u"Issues closed for {0}".format(args.milestone)
+    msg = f"Issues closed for {args.milestone}"
     print_list(msg, issues)
 
-    msg = u"Pull requests for {0}".format(args.milestone)
+    msg = f"Pull requests for {args.milestone}"
     print_list(msg, prs)
 
     return 0
 
 
 def get_milestones(getter, project):
-    url = "https://api.github.com/repos/{project}/milestones".format(project=project)
+    url = f"https://api.github.com/repos/{project}/milestones"
     data = getter.get(url)
 
     milestones = {}
     for ms in data:
-        milestones[ms[u'title']] = ms[u'number']
+        milestones[ms['title']] = ms['number']
     return milestones
 
 
@@ -95,13 +123,13 @@ def get_issues(getter, project, milestone):
     for issue_data in data:
         # don't include PRs that were closed instead
         # of merged
-        if "pull" in issue_data[u'html_url']:
-            merge_status = issue_data[u'pull_request'][u'merged_at']
+        if "pull" in issue_data['html_url']:
+            merge_status = issue_data['pull_request']['merged_at']
             if merge_status is None:
                 continue
-        issues.append(Issue(issue_data[u'number'],
-                            issue_data[u'title'],
-                            issue_data[u'html_url']))
+        issues.append(Issue(issue_data['number'],
+                            issue_data['title'],
+                            issue_data['html_url']))
     return issues
 
 
@@ -111,9 +139,10 @@ class CachedGet:
 
         self.filename = filename
         if os.path.isfile(filename):
-            print("[gh_lists] using {0} as cache (remove it if you want fresh data)".format(filename),
+            print(f"[gh_lists] using {filename} as cache "
+                  f"(remove it if you want fresh data)",
                   file=sys.stderr)
-            with open(filename, 'r', encoding='utf-8') as f:
+            with open(filename, encoding='utf-8') as f:
                 self.cache = json.load(f)
         else:
             self.cache = {}
@@ -160,7 +189,7 @@ class GithubGet:
               file=sys.stderr, flush=True)
         print("Access token: ", file=sys.stderr, end='', flush=True)
         token = input()
-        self.headers['Authorization'] = 'token {0}'.format(token.strip())
+        self.headers['Authorization'] = f'token {token.strip()}'
 
     def urlopen(self, url, auth=None):
         assert url.startswith('https://')
@@ -182,10 +211,13 @@ class GithubGet:
                 s = self.ratelimit_reset + 5 - time.time()
                 if s <= 0:
                     break
-                print("[gh_lists] rate limit exceeded: waiting until {0} ({1} s remaining)".format(
-                         datetime.datetime.fromtimestamp(self.ratelimit_reset).strftime('%Y-%m-%d %H:%M:%S'),
-                         int(s)),
-                      file=sys.stderr, flush=True)
+                print(
+                    "[gh_lists] rate limit exceeded: waiting until {} ({} s remaining)"
+                    .format(datetime.datetime.fromtimestamp(self.ratelimit_reset)
+                            .strftime('%Y-%m-%d %H:%M:%S'),
+                            int(s)),
+                    file=sys.stderr, flush=True
+                )
                 time.sleep(min(5*60, s))
 
             # Get page
