@@ -46,6 +46,7 @@ PUBLIC_SUBMODULES = [
     'cluster.vq',
     'constants',
     'datasets',
+    'differentiate',
     'fft',
     'fftpack',
     'fftpack.convolve',
@@ -59,7 +60,6 @@ PUBLIC_SUBMODULES = [
     'linalg.blas',
     'linalg.lapack',
     'linalg.interpolative',
-    'misc',
     'ndimage',
     'odr',
     'optimize',
@@ -102,6 +102,7 @@ REFGUIDE_AUTOSUMMARY_SKIPLIST = [
     r'scipy\.special\.jn',  # alias for jv
     r'scipy\.ndimage\.sum',   # alias for sum_labels
     r'scipy\.linalg\.solve_lyapunov',  # deprecated name
+    r'scipy\.signal\.sosfreqz',  # alias for freqz_sos
     r'scipy\.stats\.contingency\.chi2_contingency',
     r'scipy\.stats\.contingency\.expected_freq',
     r'scipy\.stats\.contingency\.margins',
