@@ -2,6 +2,7 @@ set -xe
 
 WHEEL="$1"
 DEST_DIR="$2"
+OPENBLAS_DIR=$(python -c"import scipy_openblas32 as sop; print(sop.get_lib_dir())")
 
 # create a temporary directory in the destination folder and unpack the wheel
 # into there
@@ -19,7 +20,6 @@ pushd scipy*
 
 for f in $(find ./scipy* -name '*.pyd'); do strip $f; done
 
-
 # now repack the wheel and overwrite the original
 wheel pack .
 mv -fv *.whl $WHEEL
@@ -27,6 +27,4 @@ mv -fv *.whl $WHEEL
 cd $DEST_DIR
 rm -rf tmp
 
-# the libopenblas.dll is placed into this directory in the cibw_before_build
-# script.
-delvewheel repair --add-path /c/opt/openblas/openblas_dll -w $DEST_DIR $WHEEL
+delvewheel repair --add-path $OPENBLAS_DIR --no-dll libsf_error_state.dll -w $DEST_DIR $WHEEL
